package org.bouncycastle.math.ec.rfc8032;

import com.google.common.base.Ascii;
import java.security.SecureRandom;
import kotlinx.coroutines.internal.LockFreeTaskQueueCore;
import org.bouncycastle.crypto.Xof;
import org.bouncycastle.crypto.digests.SHAKEDigest;
import org.bouncycastle.math.ec.rfc7748.X448;
import org.bouncycastle.math.ec.rfc7748.X448Field;
import org.bouncycastle.math.raw.Nat;
import org.bouncycastle.util.Arrays;
/* loaded from: classes4.dex */
public abstract class Ed448 {
    private static final int COORD_INTS = 14;
    private static final int C_d = -39081;
    private static final int L4_0 = 43969588;
    private static final int L4_1 = 30366549;
    private static final int L4_2 = 163752818;
    private static final int L4_3 = 258169998;
    private static final int L4_4 = 96434764;
    private static final int L4_5 = 227822194;
    private static final int L4_6 = 149865618;
    private static final int L4_7 = 550336261;
    private static final int L_0 = 78101261;
    private static final int L_1 = 141809365;
    private static final int L_2 = 175155932;
    private static final int L_3 = 64542499;
    private static final int L_4 = 158326419;
    private static final int L_5 = 191173276;
    private static final int L_6 = 104575268;
    private static final int L_7 = 137584065;
    private static final long M26L = 67108863;
    private static final long M28L = 268435455;
    private static final long M32L = 4294967295L;
    private static final int POINT_BYTES = 57;
    private static final int PRECOMP_BLOCKS = 5;
    private static final int PRECOMP_MASK = 15;
    private static final int PRECOMP_POINTS = 16;
    private static final int PRECOMP_SPACING = 18;
    private static final int PRECOMP_TEETH = 5;
    public static final int PREHASH_SIZE = 64;
    public static final int PUBLIC_KEY_SIZE = 57;
    private static final int SCALAR_BYTES = 57;
    private static final int SCALAR_INTS = 14;
    public static final int SECRET_KEY_SIZE = 57;
    public static final int SIGNATURE_SIZE = 114;
    private static final int WNAF_WIDTH_BASE = 7;
    private static final byte[] DOM4_PREFIX = {83, 105, 103, 69, 100, 52, 52, 56};
    private static final int[] P = {-1, -1, -1, -1, -1, -1, -1, -2, -1, -1, -1, -1, -1, -1};
    private static final int[] L = {-1420278541, 595116690, -1916432555, 560775794, -1361693040, -1001465015, 2093622249, -1, -1, -1, -1, -1, -1, LockFreeTaskQueueCore.MAX_CAPACITY_MASK};
    private static final int[] B_x = {118276190, 40534716, 9670182, 135141552, 85017403, 259173222, 68333082, 171784774, 174973732, 15824510, 73756743, 57518561, 94773951, 248652241, 107736333, 82941708};
    private static final int[] B_y = {36764180, 8885695, 130592152, 20104429, 163904957, 30304195, 121295871, 5901357, 125344798, 171541512, 175338348, 209069246, 3626697, 38307682, 24032956, 110359655};
    private static final Object precompLock = new Object();
    private static PointExt[] precompBaseTable = null;
    private static int[] precompBase = null;

    /* loaded from: classes4.dex */
    public static final class Algorithm {
        public static final int Ed448 = 0;
        public static final int Ed448ph = 1;
    }

    /* loaded from: classes4.dex */
    private static class F extends X448Field {
        private F() {
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes4.dex */
    public static class PointExt {
        int[] x;
        int[] y;
        int[] z;

        private PointExt() {
            this.x = F.create();
            this.y = F.create();
            this.z = F.create();
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes4.dex */
    public static class PointPrecomp {
        int[] x;
        int[] y;

        private PointPrecomp() {
            this.x = F.create();
            this.y = F.create();
        }
    }

    private static byte[] calculateS(byte[] bArr, byte[] bArr2, byte[] bArr3) {
        int[] iArr = new int[28];
        decodeScalar(bArr, 0, iArr);
        int[] iArr2 = new int[14];
        decodeScalar(bArr2, 0, iArr2);
        int[] iArr3 = new int[14];
        decodeScalar(bArr3, 0, iArr3);
        Nat.mulAddTo(14, iArr2, iArr3, iArr);
        byte[] bArr4 = new byte[114];
        for (int i = 0; i < 28; i++) {
            encode32(iArr[i], bArr4, i * 4);
        }
        return reduceScalar(bArr4);
    }

    private static boolean checkContextVar(byte[] bArr) {
        return bArr != null && bArr.length < 256;
    }

    private static int checkPoint(int[] iArr, int[] iArr2) {
        int[] create = F.create();
        int[] create2 = F.create();
        int[] create3 = F.create();
        F.sqr(iArr, create2);
        F.sqr(iArr2, create3);
        F.mul(create2, create3, create);
        F.add(create2, create3, create2);
        F.mul(create, 39081, create);
        F.subOne(create);
        F.add(create, create2, create);
        F.normalize(create);
        return F.isZero(create);
    }

    private static int checkPoint(int[] iArr, int[] iArr2, int[] iArr3) {
        int[] create = F.create();
        int[] create2 = F.create();
        int[] create3 = F.create();
        int[] create4 = F.create();
        F.sqr(iArr, create2);
        F.sqr(iArr2, create3);
        F.sqr(iArr3, create4);
        F.mul(create2, create3, create);
        F.add(create2, create3, create2);
        F.mul(create2, create4, create2);
        F.sqr(create4, create4);
        F.mul(create, 39081, create);
        F.sub(create, create4, create);
        F.add(create, create2, create);
        F.normalize(create);
        return F.isZero(create);
    }

    private static boolean checkPointVar(byte[] bArr) {
        if ((bArr[56] & Byte.MAX_VALUE) != 0) {
            return false;
        }
        int[] iArr = new int[14];
        decode32(bArr, 0, iArr, 0, 14);
        return !Nat.gte(14, iArr, P);
    }

    private static boolean checkScalarVar(byte[] bArr, int[] iArr) {
        if (bArr[56] != 0) {
            return false;
        }
        decodeScalar(bArr, 0, iArr);
        return !Nat.gte(14, iArr, L);
    }

    private static byte[] copy(byte[] bArr, int i, int i2) {
        byte[] bArr2 = new byte[i2];
        System.arraycopy(bArr, i, bArr2, 0, i2);
        return bArr2;
    }

    public static Xof createPrehash() {
        return createXof();
    }

    private static Xof createXof() {
        return new SHAKEDigest(256);
    }

    private static int decode16(byte[] bArr, int i) {
        return ((bArr[i + 1] & 255) << 8) | (bArr[i] & 255);
    }

    private static int decode24(byte[] bArr, int i) {
        int i2 = i + 1;
        return ((bArr[i2 + 1] & 255) << 16) | (bArr[i] & 255) | ((bArr[i2] & 255) << 8);
    }

    private static int decode32(byte[] bArr, int i) {
        int i2 = i + 1;
        int i3 = i2 + 1;
        return (bArr[i3 + 1] << Ascii.CAN) | (bArr[i] & 255) | ((bArr[i2] & 255) << 8) | ((bArr[i3] & 255) << 16);
    }

    private static void decode32(byte[] bArr, int i, int[] iArr, int i2, int i3) {
        for (int i4 = 0; i4 < i3; i4++) {
            iArr[i2 + i4] = decode32(bArr, (i4 * 4) + i);
        }
    }

    private static boolean decodePointVar(byte[] bArr, int i, boolean z, PointExt pointExt) {
        byte[] copy = copy(bArr, i, 57);
        if (checkPointVar(copy)) {
            byte b = copy[56];
            int i2 = (b & 128) >>> 7;
            copy[56] = (byte) (b & Byte.MAX_VALUE);
            F.decode(copy, 0, pointExt.y);
            int[] create = F.create();
            int[] create2 = F.create();
            F.sqr(pointExt.y, create);
            F.mul(create, 39081, create2);
            F.negate(create, create);
            F.addOne(create);
            F.addOne(create2);
            if (F.sqrtRatioVar(create, create2, pointExt.x)) {
                F.normalize(pointExt.x);
                if (i2 == 1 && F.isZeroVar(pointExt.x)) {
                    return false;
                }
                if (z ^ (i2 != (pointExt.x[0] & 1))) {
                    F.negate(pointExt.x, pointExt.x);
                }
                pointExtendXY(pointExt);
                return true;
            }
            return false;
        }
        return false;
    }

    private static void decodeScalar(byte[] bArr, int i, int[] iArr) {
        decode32(bArr, i, iArr, 0, 14);
    }

    private static void dom4(Xof xof, byte b, byte[] bArr) {
        byte[] bArr2 = DOM4_PREFIX;
        int length = bArr2.length;
        int i = length + 2;
        int length2 = bArr.length + i;
        byte[] bArr3 = new byte[length2];
        System.arraycopy(bArr2, 0, bArr3, 0, length);
        bArr3[length] = b;
        bArr3[length + 1] = (byte) bArr.length;
        System.arraycopy(bArr, 0, bArr3, i, bArr.length);
        xof.update(bArr3, 0, length2);
    }

    private static void encode24(int i, byte[] bArr, int i2) {
        bArr[i2] = (byte) i;
        int i3 = i2 + 1;
        bArr[i3] = (byte) (i >>> 8);
        bArr[i3 + 1] = (byte) (i >>> 16);
    }

    private static void encode32(int i, byte[] bArr, int i2) {
        bArr[i2] = (byte) i;
        int i3 = i2 + 1;
        bArr[i3] = (byte) (i >>> 8);
        int i4 = i3 + 1;
        bArr[i4] = (byte) (i >>> 16);
        bArr[i4 + 1] = (byte) (i >>> 24);
    }

    private static void encode56(long j, byte[] bArr, int i) {
        encode32((int) j, bArr, i);
        encode24((int) (j >>> 32), bArr, i + 4);
    }

    private static int encodePoint(PointExt pointExt, byte[] bArr, int i) {
        int[] create = F.create();
        int[] create2 = F.create();
        F.inv(pointExt.z, create2);
        F.mul(pointExt.x, create2, create);
        F.mul(pointExt.y, create2, create2);
        F.normalize(create);
        F.normalize(create2);
        int checkPoint = checkPoint(create, create2);
        F.encode(create2, bArr, i);
        bArr[(i + 57) - 1] = (byte) ((create[0] & 1) << 7);
        return checkPoint;
    }

    public static void generatePrivateKey(SecureRandom secureRandom, byte[] bArr) {
        secureRandom.nextBytes(bArr);
    }

    public static void generatePublicKey(byte[] bArr, int i, byte[] bArr2, int i2) {
        Xof createXof = createXof();
        byte[] bArr3 = new byte[114];
        createXof.update(bArr, i, 57);
        createXof.doFinal(bArr3, 0, 114);
        byte[] bArr4 = new byte[57];
        pruneScalar(bArr3, 0, bArr4);
        scalarMultBaseEncoded(bArr4, bArr2, i2);
    }

    private static int getWindow4(int[] iArr, int i) {
        return (iArr[i >>> 3] >>> ((i & 7) << 2)) & 15;
    }

    private static byte[] getWnafVar(int[] iArr, int i) {
        int[] iArr2 = new int[28];
        int i2 = 0;
        int i3 = 14;
        int i4 = 28;
        int i5 = 0;
        while (true) {
            i3--;
            if (i3 < 0) {
                break;
            }
            int i6 = iArr[i3];
            int i7 = i4 - 1;
            iArr2[i7] = (i5 << 16) | (i6 >>> 16);
            i4 = i7 - 1;
            iArr2[i4] = i6;
            i5 = i6;
        }
        byte[] bArr = new byte[447];
        int i8 = 32 - i;
        int i9 = 0;
        int i10 = 0;
        while (i2 < 28) {
            int i11 = iArr2[i2];
            while (i9 < 16) {
                int i12 = i11 >>> i9;
                if ((i12 & 1) == i10) {
                    i9++;
                } else {
                    int i13 = (i12 | 1) << i8;
                    bArr[(i2 << 4) + i9] = (byte) (i13 >> i8);
                    i9 += i;
                    i10 = i13 >>> 31;
                }
            }
            i2++;
            i9 -= 16;
        }
        return bArr;
    }

    private static void implSign(Xof xof, byte[] bArr, byte[] bArr2, byte[] bArr3, int i, byte[] bArr4, byte b, byte[] bArr5, int i2, int i3, byte[] bArr6, int i4) {
        dom4(xof, b, bArr4);
        xof.update(bArr, 57, 57);
        xof.update(bArr5, i2, i3);
        xof.doFinal(bArr, 0, bArr.length);
        byte[] reduceScalar = reduceScalar(bArr);
        byte[] bArr7 = new byte[57];
        scalarMultBaseEncoded(reduceScalar, bArr7, 0);
        dom4(xof, b, bArr4);
        xof.update(bArr7, 0, 57);
        xof.update(bArr3, i, 57);
        xof.update(bArr5, i2, i3);
        xof.doFinal(bArr, 0, bArr.length);
        byte[] calculateS = calculateS(reduceScalar, reduceScalar(bArr), bArr2);
        System.arraycopy(bArr7, 0, bArr6, i4, 57);
        System.arraycopy(calculateS, 0, bArr6, i4 + 57, 57);
    }

    private static void implSign(byte[] bArr, int i, byte[] bArr2, byte b, byte[] bArr3, int i2, int i3, byte[] bArr4, int i4) {
        if (!checkContextVar(bArr2)) {
            throw new IllegalArgumentException("ctx");
        }
        Xof createXof = createXof();
        byte[] bArr5 = new byte[114];
        createXof.update(bArr, i, 57);
        createXof.doFinal(bArr5, 0, 114);
        byte[] bArr6 = new byte[57];
        pruneScalar(bArr5, 0, bArr6);
        byte[] bArr7 = new byte[57];
        scalarMultBaseEncoded(bArr6, bArr7, 0);
        implSign(createXof, bArr5, bArr6, bArr7, 0, bArr2, b, bArr3, i2, i3, bArr4, i4);
    }

    private static void implSign(byte[] bArr, int i, byte[] bArr2, int i2, byte[] bArr3, byte b, byte[] bArr4, int i3, int i4, byte[] bArr5, int i5) {
        if (!checkContextVar(bArr3)) {
            throw new IllegalArgumentException("ctx");
        }
        Xof createXof = createXof();
        byte[] bArr6 = new byte[114];
        createXof.update(bArr, i, 57);
        createXof.doFinal(bArr6, 0, 114);
        byte[] bArr7 = new byte[57];
        pruneScalar(bArr6, 0, bArr7);
        implSign(createXof, bArr6, bArr7, bArr2, i2, bArr3, b, bArr4, i3, i4, bArr5, i5);
    }

    private static boolean implVerify(byte[] bArr, int i, byte[] bArr2, int i2, byte[] bArr3, byte b, byte[] bArr4, int i3, int i4) {
        if (checkContextVar(bArr3)) {
            byte[] copy = copy(bArr, i, 57);
            byte[] copy2 = copy(bArr, i + 57, 57);
            if (checkPointVar(copy)) {
                int[] iArr = new int[14];
                if (checkScalarVar(copy2, iArr)) {
                    PointExt pointExt = new PointExt();
                    if (decodePointVar(bArr2, i2, true, pointExt)) {
                        Xof createXof = createXof();
                        byte[] bArr5 = new byte[114];
                        dom4(createXof, b, bArr3);
                        createXof.update(copy, 0, 57);
                        createXof.update(bArr2, i2, 57);
                        createXof.update(bArr4, i3, i4);
                        createXof.doFinal(bArr5, 0, 114);
                        int[] iArr2 = new int[14];
                        decodeScalar(reduceScalar(bArr5), 0, iArr2);
                        PointExt pointExt2 = new PointExt();
                        scalarMultStrausVar(iArr, iArr2, pointExt, pointExt2);
                        byte[] bArr6 = new byte[57];
                        return encodePoint(pointExt2, bArr6, 0) != 0 && Arrays.areEqual(bArr6, copy);
                    }
                    return false;
                }
                return false;
            }
            return false;
        }
        throw new IllegalArgumentException("ctx");
    }

    private static boolean isNeutralElementVar(int[] iArr, int[] iArr2, int[] iArr3) {
        return F.isZeroVar(iArr) && F.areEqualVar(iArr2, iArr3);
    }

    private static void pointAdd(PointExt pointExt, PointExt pointExt2) {
        int[] create = F.create();
        int[] create2 = F.create();
        int[] create3 = F.create();
        int[] create4 = F.create();
        int[] create5 = F.create();
        int[] create6 = F.create();
        int[] create7 = F.create();
        int[] create8 = F.create();
        F.mul(pointExt.z, pointExt2.z, create);
        F.sqr(create, create2);
        F.mul(pointExt.x, pointExt2.x, create3);
        F.mul(pointExt.y, pointExt2.y, create4);
        F.mul(create3, create4, create5);
        F.mul(create5, 39081, create5);
        F.add(create2, create5, create6);
        F.sub(create2, create5, create7);
        F.add(pointExt.x, pointExt.y, create2);
        F.add(pointExt2.x, pointExt2.y, create5);
        F.mul(create2, create5, create8);
        F.add(create4, create3, create2);
        F.sub(create4, create3, create5);
        F.carry(create2);
        F.sub(create8, create2, create8);
        F.mul(create8, create, create8);
        F.mul(create5, create, create5);
        F.mul(create6, create8, pointExt2.x);
        F.mul(create5, create7, pointExt2.y);
        F.mul(create6, create7, pointExt2.z);
    }

    private static void pointAddPrecomp(PointPrecomp pointPrecomp, PointExt pointExt) {
        int[] create = F.create();
        int[] create2 = F.create();
        int[] create3 = F.create();
        int[] create4 = F.create();
        int[] create5 = F.create();
        int[] create6 = F.create();
        int[] create7 = F.create();
        F.sqr(pointExt.z, create);
        F.mul(pointPrecomp.x, pointExt.x, create2);
        F.mul(pointPrecomp.y, pointExt.y, create3);
        F.mul(create2, create3, create4);
        F.mul(create4, 39081, create4);
        F.add(create, create4, create5);
        F.sub(create, create4, create6);
        F.add(pointPrecomp.x, pointPrecomp.y, create);
        F.add(pointExt.x, pointExt.y, create4);
        F.mul(create, create4, create7);
        F.add(create3, create2, create);
        F.sub(create3, create2, create4);
        F.carry(create);
        F.sub(create7, create, create7);
        F.mul(create7, pointExt.z, create7);
        F.mul(create4, pointExt.z, create4);
        F.mul(create5, create7, pointExt.x);
        F.mul(create4, create6, pointExt.y);
        F.mul(create5, create6, pointExt.z);
    }

    private static void pointAddVar(boolean z, PointExt pointExt, PointExt pointExt2) {
        int[] iArr;
        int[] iArr2;
        int[] iArr3;
        int[] iArr4;
        int[] create = F.create();
        int[] create2 = F.create();
        int[] create3 = F.create();
        int[] create4 = F.create();
        int[] create5 = F.create();
        int[] create6 = F.create();
        int[] create7 = F.create();
        int[] create8 = F.create();
        if (z) {
            F.sub(pointExt.y, pointExt.x, create8);
            iArr2 = create2;
            iArr = create5;
            iArr4 = create6;
            iArr3 = create7;
        } else {
            F.add(pointExt.y, pointExt.x, create8);
            iArr = create2;
            iArr2 = create5;
            iArr3 = create6;
            iArr4 = create7;
        }
        F.mul(pointExt.z, pointExt2.z, create);
        F.sqr(create, create2);
        F.mul(pointExt.x, pointExt2.x, create3);
        F.mul(pointExt.y, pointExt2.y, create4);
        F.mul(create3, create4, create5);
        F.mul(create5, 39081, create5);
        F.add(create2, create5, iArr3);
        F.sub(create2, create5, iArr4);
        F.add(pointExt2.x, pointExt2.y, create5);
        F.mul(create8, create5, create8);
        F.add(create4, create3, iArr);
        F.sub(create4, create3, iArr2);
        F.carry(iArr);
        F.sub(create8, create2, create8);
        F.mul(create8, create, create8);
        F.mul(create5, create, create5);
        F.mul(create6, create8, pointExt2.x);
        F.mul(create5, create7, pointExt2.y);
        F.mul(create6, create7, pointExt2.z);
    }

    private static PointExt pointCopy(PointExt pointExt) {
        PointExt pointExt2 = new PointExt();
        pointCopy(pointExt, pointExt2);
        return pointExt2;
    }

    private static void pointCopy(PointExt pointExt, PointExt pointExt2) {
        F.copy(pointExt.x, 0, pointExt2.x, 0);
        F.copy(pointExt.y, 0, pointExt2.y, 0);
        F.copy(pointExt.z, 0, pointExt2.z, 0);
    }

    private static void pointDouble(PointExt pointExt) {
        int[] create = F.create();
        int[] create2 = F.create();
        int[] create3 = F.create();
        int[] create4 = F.create();
        int[] create5 = F.create();
        int[] create6 = F.create();
        F.add(pointExt.x, pointExt.y, create);
        F.sqr(create, create);
        F.sqr(pointExt.x, create2);
        F.sqr(pointExt.y, create3);
        F.add(create2, create3, create4);
        F.carry(create4);
        F.sqr(pointExt.z, create5);
        F.add(create5, create5, create5);
        F.carry(create5);
        F.sub(create4, create5, create6);
        F.sub(create, create4, create);
        F.sub(create2, create3, create2);
        F.mul(create, create6, pointExt.x);
        F.mul(create4, create2, pointExt.y);
        F.mul(create4, create6, pointExt.z);
    }

    private static void pointExtendXY(PointExt pointExt) {
        F.one(pointExt.z);
    }

    private static void pointLookup(int i, int i2, PointPrecomp pointPrecomp) {
        int i3 = i * 16 * 2 * 16;
        for (int i4 = 0; i4 < 16; i4++) {
            int i5 = ((i4 ^ i2) - 1) >> 31;
            F.cmov(i5, precompBase, i3, pointPrecomp.x, 0);
            int i6 = i3 + 16;
            F.cmov(i5, precompBase, i6, pointPrecomp.y, 0);
            i3 = i6 + 16;
        }
    }

    private static void pointLookup(int[] iArr, int i, int[] iArr2, PointExt pointExt) {
        int window4 = getWindow4(iArr, i);
        int i2 = (window4 >>> 3) ^ 1;
        int i3 = (window4 ^ (-i2)) & 7;
        int i4 = 0;
        for (int i5 = 0; i5 < 8; i5++) {
            int i6 = ((i5 ^ i3) - 1) >> 31;
            F.cmov(i6, iArr2, i4, pointExt.x, 0);
            int i7 = i4 + 16;
            F.cmov(i6, iArr2, i7, pointExt.y, 0);
            int i8 = i7 + 16;
            F.cmov(i6, iArr2, i8, pointExt.z, 0);
            i4 = i8 + 16;
        }
        F.cnegate(i2, pointExt.x);
    }

    private static int[] pointPrecompute(PointExt pointExt, int i) {
        PointExt pointCopy = pointCopy(pointExt);
        PointExt pointCopy2 = pointCopy(pointCopy);
        pointDouble(pointCopy2);
        int[] createTable = F.createTable(i * 3);
        int i2 = 0;
        int i3 = 0;
        while (true) {
            F.copy(pointCopy.x, 0, createTable, i2);
            int i4 = i2 + 16;
            F.copy(pointCopy.y, 0, createTable, i4);
            int i5 = i4 + 16;
            F.copy(pointCopy.z, 0, createTable, i5);
            i2 = i5 + 16;
            i3++;
            if (i3 == i) {
                return createTable;
            }
            pointAdd(pointCopy2, pointCopy);
        }
    }

    private static PointExt[] pointPrecomputeVar(PointExt pointExt, int i) {
        PointExt pointCopy = pointCopy(pointExt);
        pointDouble(pointCopy);
        PointExt[] pointExtArr = new PointExt[i];
        pointExtArr[0] = pointCopy(pointExt);
        for (int i2 = 1; i2 < i; i2++) {
            PointExt pointCopy2 = pointCopy(pointExtArr[i2 - 1]);
            pointExtArr[i2] = pointCopy2;
            pointAddVar(false, pointCopy, pointCopy2);
        }
        return pointExtArr;
    }

    private static void pointSetNeutral(PointExt pointExt) {
        F.zero(pointExt.x);
        F.one(pointExt.y);
        F.one(pointExt.z);
    }

    public static void precompute() {
        synchronized (precompLock) {
            if (precompBase != null) {
                return;
            }
            PointExt pointExt = new PointExt();
            F.copy(B_x, 0, pointExt.x, 0);
            F.copy(B_y, 0, pointExt.y, 0);
            pointExtendXY(pointExt);
            precompBaseTable = pointPrecomputeVar(pointExt, 32);
            precompBase = F.createTable(160);
            int i = 0;
            for (int i2 = 0; i2 < 5; i2++) {
                PointExt[] pointExtArr = new PointExt[5];
                PointExt pointExt2 = new PointExt();
                pointSetNeutral(pointExt2);
                int i3 = 0;
                while (true) {
                    if (i3 >= 5) {
                        break;
                    }
                    pointAddVar(true, pointExt, pointExt2);
                    pointDouble(pointExt);
                    pointExtArr[i3] = pointCopy(pointExt);
                    if (i2 + i3 != 8) {
                        for (int i4 = 1; i4 < 18; i4++) {
                            pointDouble(pointExt);
                        }
                    }
                    i3++;
                }
                PointExt[] pointExtArr2 = new PointExt[16];
                pointExtArr2[0] = pointExt2;
                int i5 = 1;
                for (int i6 = 0; i6 < 4; i6++) {
                    int i7 = 1 << i6;
                    int i8 = 0;
                    while (i8 < i7) {
                        PointExt pointCopy = pointCopy(pointExtArr2[i5 - i7]);
                        pointExtArr2[i5] = pointCopy;
                        pointAddVar(false, pointExtArr[i6], pointCopy);
                        i8++;
                        i5++;
                    }
                }
                int[] createTable = F.createTable(16);
                int[] create = F.create();
                F.copy(pointExtArr2[0].z, 0, create, 0);
                F.copy(create, 0, createTable, 0);
                int i9 = 0;
                while (true) {
                    i9++;
                    if (i9 >= 16) {
                        break;
                    }
                    F.mul(create, pointExtArr2[i9].z, create);
                    F.copy(create, 0, createTable, i9 * 16);
                }
                F.invVar(create, create);
                int i10 = i9 - 1;
                int[] create2 = F.create();
                while (i10 > 0) {
                    int i11 = i10 - 1;
                    F.copy(createTable, i11 * 16, create2, 0);
                    F.mul(create2, create, create2);
                    F.copy(create2, 0, createTable, i10 * 16);
                    F.mul(create, pointExtArr2[i10].z, create);
                    i10 = i11;
                }
                F.copy(create, 0, createTable, 0);
                for (int i12 = 0; i12 < 16; i12++) {
                    PointExt pointExt3 = pointExtArr2[i12];
                    F.copy(createTable, i12 * 16, pointExt3.z, 0);
                    F.mul(pointExt3.x, pointExt3.z, pointExt3.x);
                    F.mul(pointExt3.y, pointExt3.z, pointExt3.y);
                    F.copy(pointExt3.x, 0, precompBase, i);
                    int i13 = i + 16;
                    F.copy(pointExt3.y, 0, precompBase, i13);
                    i = i13 + 16;
                }
            }
        }
    }

    private static void pruneScalar(byte[] bArr, int i, byte[] bArr2) {
        System.arraycopy(bArr, i, bArr2, 0, 56);
        bArr2[0] = (byte) (bArr2[0] & 252);
        bArr2[55] = (byte) (bArr2[55] | 128);
        bArr2[56] = 0;
    }

    private static byte[] reduceScalar(byte[] bArr) {
        long decode24 = (decode24(bArr, 4) << 4) & 4294967295L;
        long decode32 = decode32(bArr, 7) & 4294967295L;
        long decode242 = (decode24(bArr, 11) << 4) & 4294967295L;
        long decode322 = decode32(bArr, 14) & 4294967295L;
        long decode243 = (decode24(bArr, 18) << 4) & 4294967295L;
        long decode323 = decode32(bArr, 21) & 4294967295L;
        long decode324 = decode32(bArr, 28) & 4294967295L;
        long decode244 = (decode24(bArr, 32) << 4) & 4294967295L;
        long decode325 = decode32(bArr, 35) & 4294967295L;
        long decode245 = (decode24(bArr, 39) << 4) & 4294967295L;
        long decode326 = decode32(bArr, 42) & 4294967295L;
        long decode246 = (decode24(bArr, 46) << 4) & 4294967295L;
        long decode327 = decode32(bArr, 49) & 4294967295L;
        long decode247 = (decode24(bArr, 53) << 4) & 4294967295L;
        long decode248 = (decode24(bArr, 74) << 4) & 4294967295L;
        long decode328 = decode32(bArr, 77) & 4294967295L;
        long decode249 = (decode24(bArr, 81) << 4) & 4294967295L;
        long decode329 = decode32(bArr, 84) & 4294967295L;
        long decode2410 = (decode24(bArr, 88) << 4) & 4294967295L;
        long decode3210 = decode32(bArr, 91) & 4294967295L;
        long decode2411 = (decode24(bArr, 95) << 4) & 4294967295L;
        long decode3211 = decode32(bArr, 98) & 4294967295L;
        long decode2412 = (decode24(bArr, 102) << 4) & 4294967295L;
        long decode3212 = decode32(bArr, 105) & 4294967295L;
        long decode2413 = (decode24(bArr, 109) << 4) & 4294967295L;
        long decode16 = decode16(bArr, 112) & 4294967295L;
        long j = decode2413 + (decode3212 >>> 28);
        long j2 = decode3212 & M28L;
        long decode3213 = (decode32(bArr, 56) & 4294967295L) + (decode16 * 43969588) + (j * 30366549);
        long decode2414 = ((decode24(bArr, 60) << 4) & 4294967295L) + (decode16 * 30366549) + (j * 163752818);
        long decode3214 = (decode32(bArr, 63) & 4294967295L) + (decode16 * 163752818) + (j * 258169998);
        long decode2415 = ((decode24(bArr, 67) << 4) & 4294967295L) + (decode16 * 258169998) + (j * 96434764);
        long j3 = decode328 + (decode16 * 149865618) + (j * 550336261);
        long j4 = decode327 + (j2 * 43969588);
        long j5 = decode2412 + (decode3211 >>> 28);
        long j6 = decode3211 & M28L;
        long decode3215 = (decode32(bArr, 70) & 4294967295L) + (decode16 * 96434764) + (j * 227822194) + (j2 * 149865618) + (j5 * 550336261);
        long j7 = decode326 + (j6 * 43969588);
        long j8 = decode2411 + (decode3210 >>> 28);
        long j9 = decode3210 & M28L;
        long j10 = decode3214 + (j2 * 96434764) + (j5 * 227822194) + (j6 * 149865618) + (j8 * 550336261);
        long j11 = decode325 + (j9 * 43969588);
        long j12 = decode2414 + (j2 * 258169998) + (j5 * 96434764) + (j6 * 227822194) + (j8 * 149865618) + (j9 * 550336261);
        long j13 = decode2410 + (decode329 >>> 28);
        long j14 = decode329 & M28L;
        long j15 = decode248 + (decode16 * 227822194) + (j * 149865618) + (j2 * 550336261) + (decode3215 >>> 28);
        long j16 = decode3215 & M28L;
        long j17 = j3 + (j15 >>> 28);
        long j18 = j15 & M28L;
        long j19 = decode249 + (decode16 * 550336261) + (j17 >>> 28);
        long j20 = j17 & M28L;
        long j21 = j14 + (j19 >>> 28);
        long j22 = j19 & M28L;
        long decode2416 = ((decode24(bArr, 25) << 4) & 4294967295L) + (j22 * 43969588);
        long j23 = decode324 + (j21 * 43969588) + (j22 * 30366549);
        long j24 = decode244 + (j13 * 43969588) + (j21 * 30366549) + (j22 * 163752818);
        long j25 = j11 + (j13 * 30366549) + (j21 * 163752818) + (j22 * 258169998);
        long j26 = decode245 + (j8 * 43969588) + (j9 * 30366549) + (j13 * 163752818) + (j21 * 258169998) + (j22 * 96434764);
        long j27 = j7 + (j8 * 30366549) + (j9 * 163752818) + (j13 * 258169998) + (j21 * 96434764) + (j22 * 227822194);
        long j28 = j4 + (j5 * 30366549) + (j6 * 163752818) + (j8 * 258169998) + (j9 * 96434764) + (j13 * 227822194) + (j21 * 149865618) + (j22 * 550336261);
        long j29 = decode323 + (j20 * 43969588);
        long j30 = j10 + (j12 >>> 28);
        long j31 = j12 & M28L;
        long j32 = decode2415 + (j2 * 227822194) + (j5 * 149865618) + (j6 * 550336261) + (j30 >>> 28);
        long j33 = j30 & M28L;
        long j34 = j16 + (j32 >>> 28);
        long j35 = j32 & M28L;
        long j36 = j18 + (j34 >>> 28);
        long j37 = j34 & M28L;
        long j38 = j26 + (j20 * 227822194) + (j36 * 149865618) + (j37 * 550336261);
        long j39 = decode322 + (j37 * 43969588) + (j35 * 30366549);
        long j40 = decode243 + (j36 * 43969588) + (j37 * 30366549) + (j35 * 163752818);
        long j41 = j29 + (j36 * 30366549) + (j37 * 163752818) + (j35 * 258169998);
        long j42 = decode2416 + (j20 * 30366549) + (j36 * 163752818) + (j37 * 258169998) + (j35 * 96434764);
        long j43 = j23 + (j20 * 163752818) + (j36 * 258169998) + (j37 * 96434764) + (j35 * 227822194);
        long j44 = j24 + (j20 * 258169998) + (j36 * 96434764) + (j37 * 227822194) + (j35 * 149865618);
        long j45 = j25 + (j20 * 96434764) + (j36 * 227822194) + (j37 * 149865618) + (j35 * 550336261);
        long j46 = decode247 + (j * 43969588) + (j2 * 30366549) + (j5 * 163752818) + (j6 * 258169998) + (j8 * 96434764) + (j9 * 227822194) + (j13 * 149865618) + (j21 * 550336261) + (j28 >>> 28);
        long j47 = j28 & M28L;
        long j48 = decode3213 + (j2 * 163752818) + (j5 * 258169998) + (j6 * 96434764) + (j8 * 227822194) + (j9 * 149865618) + (j13 * 550336261) + (j46 >>> 28);
        long j49 = j46 & M28L;
        long j50 = j31 + (j48 >>> 28);
        long j51 = j48 & M28L;
        long j52 = j33 + (j50 >>> 28);
        long j53 = j50 & M28L;
        long j54 = decode32 + (j52 * 43969588);
        long j55 = decode242 + (j35 * 43969588) + (j52 * 30366549);
        long j56 = j39 + (j52 * 163752818);
        long j57 = j40 + (j52 * 258169998);
        long j58 = j41 + (j52 * 96434764);
        long j59 = j42 + (j52 * 227822194);
        long j60 = j44 + (j52 * 550336261);
        long j61 = j49 & M26L;
        long j62 = (j51 * 4) + (j49 >>> 26) + 1;
        long decode3216 = (decode32(bArr, 0) & 4294967295L) + (78101261 * j62);
        long j63 = j54 + (30366549 * j53) + (175155932 * j62);
        long j64 = j55 + (163752818 * j53) + (64542499 * j62);
        long j65 = j56 + (258169998 * j53) + (158326419 * j62);
        long j66 = j57 + (96434764 * j53) + (191173276 * j62);
        long j67 = j59 + (149865618 * j53) + (j62 * 137584065);
        long j68 = decode24 + (43969588 * j53) + (141809365 * j62) + (decode3216 >>> 28);
        long j69 = decode3216 & M28L;
        long j70 = j63 + (j68 >>> 28);
        long j71 = j68 & M28L;
        long j72 = j64 + (j70 >>> 28);
        long j73 = j70 & M28L;
        long j74 = j65 + (j72 >>> 28);
        long j75 = j72 & M28L;
        long j76 = j66 + (j74 >>> 28);
        long j77 = j74 & M28L;
        long j78 = j58 + (227822194 * j53) + (104575268 * j62) + (j76 >>> 28);
        long j79 = j76 & M28L;
        long j80 = j67 + (j78 >>> 28);
        long j81 = j78 & M28L;
        long j82 = j43 + (j52 * 149865618) + (j53 * 550336261) + (j80 >>> 28);
        long j83 = j80 & M28L;
        long j84 = j60 + (j82 >>> 28);
        long j85 = j82 & M28L;
        long j86 = j45 + (j84 >>> 28);
        long j87 = j84 & M28L;
        long j88 = j38 + (j86 >>> 28);
        long j89 = j86 & M28L;
        long j90 = j27 + (j20 * 149865618) + (j36 * 550336261) + (j88 >>> 28);
        long j91 = j88 & M28L;
        long j92 = decode246 + (j5 * 43969588) + (j6 * 30366549) + (j8 * 163752818) + (j9 * 258169998) + (j13 * 96434764) + (j21 * 227822194) + (j22 * 149865618) + (j20 * 550336261) + (j90 >>> 28);
        long j93 = j90 & M28L;
        long j94 = j47 + (j92 >>> 28);
        long j95 = j92 & M28L;
        long j96 = j61 + (j94 >>> 28);
        long j97 = j94 & M28L;
        long j98 = j96 & M26L;
        long j99 = (j96 >>> 26) - 1;
        long j100 = j69 - (j99 & 78101261);
        long j101 = (j71 - (j99 & 141809365)) + (j100 >> 28);
        long j102 = j100 & M28L;
        long j103 = (j73 - (j99 & 175155932)) + (j101 >> 28);
        long j104 = j101 & M28L;
        long j105 = (j75 - (j99 & 64542499)) + (j103 >> 28);
        long j106 = j103 & M28L;
        long j107 = (j77 - (j99 & 158326419)) + (j105 >> 28);
        long j108 = j105 & M28L;
        long j109 = (j79 - (j99 & 191173276)) + (j107 >> 28);
        long j110 = j107 & M28L;
        long j111 = (j81 - (j99 & 104575268)) + (j109 >> 28);
        long j112 = j109 & M28L;
        long j113 = (j83 - (j99 & 137584065)) + (j111 >> 28);
        long j114 = j111 & M28L;
        long j115 = j85 + (j113 >> 28);
        long j116 = j113 & M28L;
        long j117 = j87 + (j115 >> 28);
        long j118 = j115 & M28L;
        long j119 = j89 + (j117 >> 28);
        long j120 = j117 & M28L;
        long j121 = j91 + (j119 >> 28);
        long j122 = j119 & M28L;
        long j123 = j93 + (j121 >> 28);
        long j124 = j121 & M28L;
        long j125 = j95 + (j123 >> 28);
        long j126 = j123 & M28L;
        long j127 = j97 + (j125 >> 28);
        long j128 = j125 & M28L;
        long j129 = j127 & M28L;
        byte[] bArr2 = new byte[57];
        encode56((j104 << 28) | j102, bArr2, 0);
        encode56((j108 << 28) | j106, bArr2, 7);
        encode56(j110 | (j112 << 28), bArr2, 14);
        encode56(j114 | (j116 << 28), bArr2, 21);
        encode56(j118 | (j120 << 28), bArr2, 28);
        encode56(j122 | (j124 << 28), bArr2, 35);
        encode56(j126 | (j128 << 28), bArr2, 42);
        encode56(((j98 + (j127 >> 28)) << 28) | j129, bArr2, 49);
        return bArr2;
    }

    private static void scalarMult(byte[] bArr, PointExt pointExt, PointExt pointExt2) {
        int[] iArr = new int[14];
        decodeScalar(bArr, 0, iArr);
        Nat.shiftDownBits(14, iArr, 2, 0);
        Nat.cadd(14, (~iArr[0]) & 1, iArr, L, iArr);
        Nat.shiftDownBit(14, iArr, 1);
        int[] pointPrecompute = pointPrecompute(pointExt, 8);
        PointExt pointExt3 = new PointExt();
        pointLookup(iArr, 111, pointPrecompute, pointExt2);
        for (int i = 110; i >= 0; i--) {
            for (int i2 = 0; i2 < 4; i2++) {
                pointDouble(pointExt2);
            }
            pointLookup(iArr, i, pointPrecompute, pointExt3);
            pointAdd(pointExt3, pointExt2);
        }
        for (int i3 = 0; i3 < 2; i3++) {
            pointDouble(pointExt2);
        }
    }

    private static void scalarMultBase(byte[] bArr, PointExt pointExt) {
        precompute();
        int[] iArr = new int[15];
        decodeScalar(bArr, 0, iArr);
        iArr[14] = Nat.cadd(14, (~iArr[0]) & 1, iArr, L, iArr) + 4;
        Nat.shiftDownBit(15, iArr, 0);
        PointPrecomp pointPrecomp = new PointPrecomp();
        pointSetNeutral(pointExt);
        int i = 17;
        while (true) {
            int i2 = i;
            for (int i3 = 0; i3 < 5; i3++) {
                int i4 = 0;
                for (int i5 = 0; i5 < 5; i5++) {
                    i4 = (i4 & (~(1 << i5))) ^ ((iArr[i2 >>> 5] >>> (i2 & 31)) << i5);
                    i2 += 18;
                }
                int i6 = (i4 >>> 4) & 1;
                pointLookup(i3, ((-i6) ^ i4) & 15, pointPrecomp);
                F.cnegate(i6, pointPrecomp.x);
                pointAddPrecomp(pointPrecomp, pointExt);
            }
            i--;
            if (i < 0) {
                return;
            }
            pointDouble(pointExt);
        }
    }

    private static void scalarMultBaseEncoded(byte[] bArr, byte[] bArr2, int i) {
        PointExt pointExt = new PointExt();
        scalarMultBase(bArr, pointExt);
        if (encodePoint(pointExt, bArr2, i) == 0) {
            throw new IllegalStateException();
        }
    }

    public static void scalarMultBaseXY(X448.Friend friend, byte[] bArr, int i, int[] iArr, int[] iArr2) {
        if (friend == null) {
            throw new NullPointerException("This method is only for use by X448");
        }
        byte[] bArr2 = new byte[57];
        pruneScalar(bArr, i, bArr2);
        PointExt pointExt = new PointExt();
        scalarMultBase(bArr2, pointExt);
        if (checkPoint(pointExt.x, pointExt.y, pointExt.z) == 0) {
            throw new IllegalStateException();
        }
        F.copy(pointExt.x, 0, iArr, 0);
        F.copy(pointExt.y, 0, iArr2, 0);
    }

    private static void scalarMultOrderVar(PointExt pointExt, PointExt pointExt2) {
        byte[] wnafVar = getWnafVar(L, 5);
        PointExt[] pointPrecomputeVar = pointPrecomputeVar(pointExt, 8);
        pointSetNeutral(pointExt2);
        int i = 446;
        while (true) {
            byte b = wnafVar[i];
            if (b != 0) {
                int i2 = b >> Ascii.US;
                pointAddVar(i2 != 0, pointPrecomputeVar[(b ^ i2) >>> 1], pointExt2);
            }
            i--;
            if (i < 0) {
                return;
            }
            pointDouble(pointExt2);
        }
    }

    private static void scalarMultStrausVar(int[] iArr, int[] iArr2, PointExt pointExt, PointExt pointExt2) {
        precompute();
        byte[] wnafVar = getWnafVar(iArr, 7);
        byte[] wnafVar2 = getWnafVar(iArr2, 5);
        PointExt[] pointPrecomputeVar = pointPrecomputeVar(pointExt, 8);
        pointSetNeutral(pointExt2);
        int i = 446;
        while (true) {
            byte b = wnafVar[i];
            if (b != 0) {
                int i2 = b >> Ascii.US;
                pointAddVar(i2 != 0, precompBaseTable[(b ^ i2) >>> 1], pointExt2);
            }
            byte b2 = wnafVar2[i];
            if (b2 != 0) {
                int i3 = b2 >> Ascii.US;
                pointAddVar(i3 != 0, pointPrecomputeVar[(b2 ^ i3) >>> 1], pointExt2);
            }
            i--;
            if (i < 0) {
                return;
            }
            pointDouble(pointExt2);
        }
    }

    public static void sign(byte[] bArr, int i, byte[] bArr2, int i2, byte[] bArr3, byte[] bArr4, int i3, int i4, byte[] bArr5, int i5) {
        implSign(bArr, i, bArr2, i2, bArr3, (byte) 0, bArr4, i3, i4, bArr5, i5);
    }

    public static void sign(byte[] bArr, int i, byte[] bArr2, byte[] bArr3, int i2, int i3, byte[] bArr4, int i4) {
        implSign(bArr, i, bArr2, (byte) 0, bArr3, i2, i3, bArr4, i4);
    }

    public static void signPrehash(byte[] bArr, int i, byte[] bArr2, int i2, byte[] bArr3, Xof xof, byte[] bArr4, int i3) {
        byte[] bArr5 = new byte[64];
        if (64 != xof.doFinal(bArr5, 0, 64)) {
            throw new IllegalArgumentException("ph");
        }
        implSign(bArr, i, bArr2, i2, bArr3, (byte) 1, bArr5, 0, 64, bArr4, i3);
    }

    public static void signPrehash(byte[] bArr, int i, byte[] bArr2, int i2, byte[] bArr3, byte[] bArr4, int i3, byte[] bArr5, int i4) {
        implSign(bArr, i, bArr2, i2, bArr3, (byte) 1, bArr4, i3, 64, bArr5, i4);
    }

    public static void signPrehash(byte[] bArr, int i, byte[] bArr2, Xof xof, byte[] bArr3, int i2) {
        byte[] bArr4 = new byte[64];
        if (64 != xof.doFinal(bArr4, 0, 64)) {
            throw new IllegalArgumentException("ph");
        }
        implSign(bArr, i, bArr2, (byte) 1, bArr4, 0, 64, bArr3, i2);
    }

    public static void signPrehash(byte[] bArr, int i, byte[] bArr2, byte[] bArr3, int i2, byte[] bArr4, int i3) {
        implSign(bArr, i, bArr2, (byte) 1, bArr3, i2, 64, bArr4, i3);
    }

    public static boolean validatePublicKeyFull(byte[] bArr, int i) {
        PointExt pointExt = new PointExt();
        if (decodePointVar(bArr, i, false, pointExt)) {
            F.normalize(pointExt.x);
            F.normalize(pointExt.y);
            F.normalize(pointExt.z);
            if (isNeutralElementVar(pointExt.x, pointExt.y, pointExt.z)) {
                return false;
            }
            PointExt pointExt2 = new PointExt();
            scalarMultOrderVar(pointExt, pointExt2);
            F.normalize(pointExt2.x);
            F.normalize(pointExt2.y);
            F.normalize(pointExt2.z);
            return isNeutralElementVar(pointExt2.x, pointExt2.y, pointExt2.z);
        }
        return false;
    }

    public static boolean validatePublicKeyPartial(byte[] bArr, int i) {
        return decodePointVar(bArr, i, false, new PointExt());
    }

    public static boolean verify(byte[] bArr, int i, byte[] bArr2, int i2, byte[] bArr3, byte[] bArr4, int i3, int i4) {
        return implVerify(bArr, i, bArr2, i2, bArr3, (byte) 0, bArr4, i3, i4);
    }

    public static boolean verifyPrehash(byte[] bArr, int i, byte[] bArr2, int i2, byte[] bArr3, Xof xof) {
        byte[] bArr4 = new byte[64];
        if (64 == xof.doFinal(bArr4, 0, 64)) {
            return implVerify(bArr, i, bArr2, i2, bArr3, (byte) 1, bArr4, 0, 64);
        }
        throw new IllegalArgumentException("ph");
    }

    public static boolean verifyPrehash(byte[] bArr, int i, byte[] bArr2, int i2, byte[] bArr3, byte[] bArr4, int i3) {
        return implVerify(bArr, i, bArr2, i2, bArr3, (byte) 1, bArr4, i3, 64);
    }
}
