package org.bouncycastle.x509;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.math.BigInteger;
import java.net.HttpURLConnection;
import java.net.InetAddress;
import java.net.URL;
import java.security.GeneralSecurityException;
import java.security.PublicKey;
import java.security.SignatureException;
import java.security.cert.CertPath;
import java.security.cert.CertPathValidatorException;
import java.security.cert.Certificate;
import java.security.cert.CertificateFactory;
import java.security.cert.PKIXCertPathChecker;
import java.security.cert.PKIXParameters;
import java.security.cert.PolicyNode;
import java.security.cert.TrustAnchor;
import java.security.cert.X509CRL;
import java.security.cert.X509CertSelector;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Set;
import java.util.Vector;
import javax.security.auth.x500.X500Principal;
import org.apache.commons.lang3.StringUtils;
import org.bouncycastle.asn1.ASN1IA5String;
import org.bouncycastle.asn1.ASN1InputStream;
import org.bouncycastle.asn1.ASN1Integer;
import org.bouncycastle.asn1.ASN1ObjectIdentifier;
import org.bouncycastle.asn1.ASN1OctetString;
import org.bouncycastle.asn1.ASN1Primitive;
import org.bouncycastle.asn1.ASN1Sequence;
import org.bouncycastle.asn1.ASN1TaggedObject;
import org.bouncycastle.asn1.DEROctetString;
import org.bouncycastle.asn1.x509.AccessDescription;
import org.bouncycastle.asn1.x509.AlgorithmIdentifier;
import org.bouncycastle.asn1.x509.AuthorityInformationAccess;
import org.bouncycastle.asn1.x509.AuthorityKeyIdentifier;
import org.bouncycastle.asn1.x509.BasicConstraints;
import org.bouncycastle.asn1.x509.CRLDistPoint;
import org.bouncycastle.asn1.x509.DistributionPoint;
import org.bouncycastle.asn1.x509.DistributionPointName;
import org.bouncycastle.asn1.x509.Extension;
import org.bouncycastle.asn1.x509.GeneralName;
import org.bouncycastle.asn1.x509.GeneralNames;
import org.bouncycastle.asn1.x509.GeneralSubtree;
import org.bouncycastle.asn1.x509.NameConstraints;
import org.bouncycastle.asn1.x509.PolicyInformation;
import org.bouncycastle.asn1.x509.qualified.MonetaryValue;
import org.bouncycastle.asn1.x509.qualified.QCStatement;
import org.bouncycastle.i18n.ErrorBundle;
import org.bouncycastle.i18n.LocaleString;
import org.bouncycastle.i18n.filter.TrustedInput;
import org.bouncycastle.i18n.filter.UntrustedInput;
import org.bouncycastle.i18n.filter.UntrustedUrlInput;
import org.bouncycastle.jce.provider.AnnotatedException;
import org.bouncycastle.jce.provider.BouncyCastleProvider;
import org.bouncycastle.jce.provider.PKIXNameConstraintValidator;
import org.bouncycastle.jce.provider.PKIXNameConstraintValidatorException;
import org.bouncycastle.jce.provider.PKIXPolicyNode;
import org.bouncycastle.jce.provider.RFC3280CertPathUtilities;
import org.bouncycastle.util.Integers;
/* loaded from: classes2.dex */
public class PKIXCertPathReviewer extends CertPathValidatorUtilities {
    private static final String RESOURCE_NAME = "org.bouncycastle.x509.CertPathReviewerMessages";
    protected CertPath certPath;
    protected List certs;
    protected Date currentDate;
    protected List[] errors;
    private boolean initialized;
    protected int n;
    protected List[] notifications;
    protected PKIXParameters pkixParams;
    protected PolicyNode policyTree;
    protected PublicKey subjectPublicKey;
    protected TrustAnchor trustAnchor;
    protected Date validDate;
    private static final String QC_STATEMENT = Extension.qCStatements.getId();
    private static final String CRL_DIST_POINTS = Extension.cRLDistributionPoints.getId();
    private static final String AUTH_INFO_ACCESS = Extension.authorityInfoAccess.getId();

    public PKIXCertPathReviewer() {
    }

    public PKIXCertPathReviewer(CertPath certPath, PKIXParameters pKIXParameters) throws CertPathReviewerException {
        init(certPath, pKIXParameters);
    }

    private String IPtoString(byte[] bArr) {
        try {
            return InetAddress.getByAddress(bArr).getHostAddress();
        } catch (Exception unused) {
            StringBuffer stringBuffer = new StringBuffer();
            for (int i = 0; i != bArr.length; i++) {
                stringBuffer.append(Integer.toHexString(bArr[i] & 255));
                stringBuffer.append(' ');
            }
            return stringBuffer.toString();
        }
    }

    private void checkCriticalExtensions() {
        List<PKIXCertPathChecker> certPathCheckers = this.pkixParams.getCertPathCheckers();
        for (PKIXCertPathChecker pKIXCertPathChecker : certPathCheckers) {
            try {
                try {
                    pKIXCertPathChecker.init(false);
                } catch (CertPathValidatorException e) {
                    throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.certPathCheckerError", new Object[]{e.getMessage(), e, e.getClass().getName()}), e);
                }
            } catch (CertPathReviewerException e2) {
                addError(e2.getErrorMessage(), e2.getIndex());
                return;
            }
        }
        for (int size = this.certs.size() - 1; size >= 0; size--) {
            X509Certificate x509Certificate = (X509Certificate) this.certs.get(size);
            Set<String> criticalExtensionOIDs = x509Certificate.getCriticalExtensionOIDs();
            if (criticalExtensionOIDs != null && !criticalExtensionOIDs.isEmpty()) {
                criticalExtensionOIDs.remove(KEY_USAGE);
                criticalExtensionOIDs.remove(CERTIFICATE_POLICIES);
                criticalExtensionOIDs.remove(POLICY_MAPPINGS);
                criticalExtensionOIDs.remove(INHIBIT_ANY_POLICY);
                criticalExtensionOIDs.remove(ISSUING_DISTRIBUTION_POINT);
                criticalExtensionOIDs.remove(DELTA_CRL_INDICATOR);
                criticalExtensionOIDs.remove(POLICY_CONSTRAINTS);
                criticalExtensionOIDs.remove(BASIC_CONSTRAINTS);
                criticalExtensionOIDs.remove(SUBJECT_ALTERNATIVE_NAME);
                criticalExtensionOIDs.remove(NAME_CONSTRAINTS);
                if (size == 0) {
                    criticalExtensionOIDs.remove(Extension.extendedKeyUsage.getId());
                }
                String str = QC_STATEMENT;
                if (criticalExtensionOIDs.contains(str) && processQcStatements(x509Certificate, size)) {
                    criticalExtensionOIDs.remove(str);
                }
                for (PKIXCertPathChecker pKIXCertPathChecker2 : certPathCheckers) {
                    try {
                        pKIXCertPathChecker2.check(x509Certificate, criticalExtensionOIDs);
                    } catch (CertPathValidatorException e3) {
                        throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.criticalExtensionError", new Object[]{e3.getMessage(), e3, e3.getClass().getName()}), e3.getCause(), this.certPath, size);
                    }
                }
                if (!criticalExtensionOIDs.isEmpty()) {
                    Iterator<String> it = criticalExtensionOIDs.iterator();
                    while (it.hasNext()) {
                        addError(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.unknownCriticalExt", new Object[]{new ASN1ObjectIdentifier(it.next())}), size);
                    }
                }
            }
        }
    }

    private void checkNameConstraints() {
        PKIXNameConstraintValidator pKIXNameConstraintValidator = new PKIXNameConstraintValidator();
        try {
            for (int size = this.certs.size() - 1; size > 0; size--) {
                X509Certificate x509Certificate = (X509Certificate) this.certs.get(size);
                if (!isSelfIssued(x509Certificate)) {
                    X500Principal subjectPrincipal = getSubjectPrincipal(x509Certificate);
                    try {
                        ASN1Sequence aSN1Sequence = (ASN1Sequence) new ASN1InputStream(new ByteArrayInputStream(subjectPrincipal.getEncoded())).readObject();
                        try {
                            pKIXNameConstraintValidator.checkPermittedDN(aSN1Sequence);
                            try {
                                pKIXNameConstraintValidator.checkExcludedDN(aSN1Sequence);
                                try {
                                    ASN1Sequence aSN1Sequence2 = (ASN1Sequence) getExtensionValue(x509Certificate, SUBJECT_ALTERNATIVE_NAME);
                                    if (aSN1Sequence2 != null) {
                                        for (int i = 0; i < aSN1Sequence2.size(); i++) {
                                            GeneralName generalName = GeneralName.getInstance(aSN1Sequence2.getObjectAt(i));
                                            try {
                                                pKIXNameConstraintValidator.checkPermitted(generalName);
                                                pKIXNameConstraintValidator.checkExcluded(generalName);
                                            } catch (PKIXNameConstraintValidatorException e) {
                                                throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.notPermittedEmail", new Object[]{new UntrustedInput(generalName)}), e, this.certPath, size);
                                            }
                                        }
                                    }
                                } catch (AnnotatedException e2) {
                                    throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.subjAltNameExtError"), e2, this.certPath, size);
                                }
                            } catch (PKIXNameConstraintValidatorException e3) {
                                throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.excludedDN", new Object[]{new UntrustedInput(subjectPrincipal.getName())}), e3, this.certPath, size);
                            }
                        } catch (PKIXNameConstraintValidatorException e4) {
                            throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.notPermittedDN", new Object[]{new UntrustedInput(subjectPrincipal.getName())}), e4, this.certPath, size);
                        }
                    } catch (IOException e5) {
                        throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.ncSubjectNameError", new Object[]{new UntrustedInput(subjectPrincipal)}), e5, this.certPath, size);
                    }
                }
                try {
                    ASN1Sequence aSN1Sequence3 = (ASN1Sequence) getExtensionValue(x509Certificate, NAME_CONSTRAINTS);
                    if (aSN1Sequence3 != null) {
                        NameConstraints nameConstraints = NameConstraints.getInstance(aSN1Sequence3);
                        GeneralSubtree[] permittedSubtrees = nameConstraints.getPermittedSubtrees();
                        if (permittedSubtrees != null) {
                            pKIXNameConstraintValidator.intersectPermittedSubtree(permittedSubtrees);
                        }
                        GeneralSubtree[] excludedSubtrees = nameConstraints.getExcludedSubtrees();
                        if (excludedSubtrees != null) {
                            for (int i2 = 0; i2 != excludedSubtrees.length; i2++) {
                                pKIXNameConstraintValidator.addExcludedSubtree(excludedSubtrees[i2]);
                            }
                        }
                    }
                } catch (AnnotatedException e6) {
                    throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.ncExtError"), e6, this.certPath, size);
                }
            }
        } catch (CertPathReviewerException e7) {
            addError(e7.getErrorMessage(), e7.getIndex());
        }
    }

    private void checkPathLength() {
        BasicConstraints basicConstraints;
        BigInteger pathLenConstraint;
        int intValue;
        int i = this.n;
        int i2 = 0;
        for (int size = this.certs.size() - 1; size > 0; size--) {
            X509Certificate x509Certificate = (X509Certificate) this.certs.get(size);
            if (!isSelfIssued(x509Certificate)) {
                if (i <= 0) {
                    addError(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.pathLengthExtended"));
                }
                i--;
                i2++;
            }
            try {
                basicConstraints = BasicConstraints.getInstance(getExtensionValue(x509Certificate, BASIC_CONSTRAINTS));
            } catch (AnnotatedException unused) {
                addError(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.processLengthConstError"), size);
                basicConstraints = null;
            }
            if (basicConstraints != null && (pathLenConstraint = basicConstraints.getPathLenConstraint()) != null && (intValue = pathLenConstraint.intValue()) < i) {
                i = intValue;
            }
        }
        addNotification(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.totalPathLength", new Object[]{Integers.valueOf(i2)}));
    }

    /* JADX WARN: Removed duplicated region for block: B:109:0x023f A[Catch: CertPathReviewerException -> 0x05f9, TryCatch #3 {CertPathReviewerException -> 0x05f9, blocks: (B:17:0x006f, B:21:0x007f, B:23:0x008c, B:27:0x009c, B:28:0x00a7, B:30:0x00ad, B:32:0x00ce, B:33:0x00d6, B:35:0x00dc, B:37:0x00e1, B:38:0x00ed, B:42:0x00f9, B:45:0x0100, B:46:0x0109, B:48:0x010f, B:50:0x0119, B:53:0x0120, B:55:0x0124, B:95:0x0210, B:97:0x0216, B:98:0x0219, B:100:0x021f, B:102:0x022b, B:105:0x0233, B:106:0x0236, B:107:0x0239, B:109:0x023f, B:110:0x0248, B:112:0x024e, B:120:0x0271, B:121:0x027d, B:122:0x027e, B:124:0x0282, B:126:0x028a, B:127:0x028e, B:129:0x0294, B:132:0x02b6, B:134:0x02c0, B:135:0x02c5, B:136:0x02d1, B:137:0x02d2, B:138:0x02de, B:140:0x02e1, B:141:0x02ee, B:143:0x02f4, B:145:0x031a, B:147:0x0332, B:146:0x0329, B:148:0x0339, B:149:0x033f, B:151:0x0345, B:153:0x034d, B:164:0x0377, B:157:0x0355, B:158:0x0361, B:160:0x0363, B:161:0x0372, B:167:0x0380, B:178:0x039f, B:180:0x03a9, B:181:0x03ad, B:183:0x03b3, B:188:0x03c3, B:191:0x03d0, B:194:0x03dd, B:196:0x03e7, B:207:0x0425, B:199:0x03ef, B:200:0x03fd, B:201:0x03fe, B:202:0x040c, B:204:0x040e, B:205:0x041c, B:59:0x0133, B:60:0x0137, B:62:0x013d, B:64:0x0153, B:66:0x015d, B:67:0x0162, B:69:0x0168, B:70:0x0176, B:72:0x017c, B:74:0x0188, B:78:0x0195, B:79:0x019b, B:81:0x01a1, B:86:0x01ba, B:75:0x018b, B:77:0x018f, B:90:0x01f3, B:93:0x0203, B:94:0x020f, B:209:0x0434, B:210:0x0441, B:211:0x0442, B:215:0x0453, B:217:0x045d, B:218:0x0462, B:220:0x0468, B:223:0x0476, B:230:0x048b, B:309:0x05df, B:310:0x05eb, B:233:0x0496, B:234:0x04a2, B:235:0x04a3, B:237:0x04a9, B:239:0x04b1, B:241:0x04b7, B:244:0x04c1, B:245:0x04c4, B:247:0x04ca, B:249:0x04da, B:250:0x04de, B:252:0x04e4, B:253:0x04ec, B:254:0x04ef, B:255:0x04f4, B:256:0x04f8, B:258:0x04fe, B:260:0x050e, B:262:0x0516, B:263:0x0519, B:265:0x051f, B:267:0x052b, B:268:0x052f, B:269:0x0532, B:270:0x0535, B:271:0x0541, B:273:0x0546, B:275:0x0550, B:276:0x0553, B:278:0x0559, B:280:0x0569, B:281:0x056d, B:283:0x0573, B:285:0x0583, B:286:0x0587, B:287:0x058a, B:288:0x058d, B:289:0x0593, B:291:0x0599, B:293:0x05ab, B:296:0x05b5, B:298:0x05bb, B:299:0x05be, B:301:0x05c4, B:303:0x05d0, B:304:0x05d4, B:305:0x05d7, B:311:0x05ec, B:312:0x05f8), top: B:322:0x006f, inners: #0, #1, #2, #4, #5, #6, #7, #8, #9 }] */
    /* JADX WARN: Removed duplicated region for block: B:53:0x0120 A[Catch: CertPathReviewerException -> 0x05f9, TryCatch #3 {CertPathReviewerException -> 0x05f9, blocks: (B:17:0x006f, B:21:0x007f, B:23:0x008c, B:27:0x009c, B:28:0x00a7, B:30:0x00ad, B:32:0x00ce, B:33:0x00d6, B:35:0x00dc, B:37:0x00e1, B:38:0x00ed, B:42:0x00f9, B:45:0x0100, B:46:0x0109, B:48:0x010f, B:50:0x0119, B:53:0x0120, B:55:0x0124, B:95:0x0210, B:97:0x0216, B:98:0x0219, B:100:0x021f, B:102:0x022b, B:105:0x0233, B:106:0x0236, B:107:0x0239, B:109:0x023f, B:110:0x0248, B:112:0x024e, B:120:0x0271, B:121:0x027d, B:122:0x027e, B:124:0x0282, B:126:0x028a, B:127:0x028e, B:129:0x0294, B:132:0x02b6, B:134:0x02c0, B:135:0x02c5, B:136:0x02d1, B:137:0x02d2, B:138:0x02de, B:140:0x02e1, B:141:0x02ee, B:143:0x02f4, B:145:0x031a, B:147:0x0332, B:146:0x0329, B:148:0x0339, B:149:0x033f, B:151:0x0345, B:153:0x034d, B:164:0x0377, B:157:0x0355, B:158:0x0361, B:160:0x0363, B:161:0x0372, B:167:0x0380, B:178:0x039f, B:180:0x03a9, B:181:0x03ad, B:183:0x03b3, B:188:0x03c3, B:191:0x03d0, B:194:0x03dd, B:196:0x03e7, B:207:0x0425, B:199:0x03ef, B:200:0x03fd, B:201:0x03fe, B:202:0x040c, B:204:0x040e, B:205:0x041c, B:59:0x0133, B:60:0x0137, B:62:0x013d, B:64:0x0153, B:66:0x015d, B:67:0x0162, B:69:0x0168, B:70:0x0176, B:72:0x017c, B:74:0x0188, B:78:0x0195, B:79:0x019b, B:81:0x01a1, B:86:0x01ba, B:75:0x018b, B:77:0x018f, B:90:0x01f3, B:93:0x0203, B:94:0x020f, B:209:0x0434, B:210:0x0441, B:211:0x0442, B:215:0x0453, B:217:0x045d, B:218:0x0462, B:220:0x0468, B:223:0x0476, B:230:0x048b, B:309:0x05df, B:310:0x05eb, B:233:0x0496, B:234:0x04a2, B:235:0x04a3, B:237:0x04a9, B:239:0x04b1, B:241:0x04b7, B:244:0x04c1, B:245:0x04c4, B:247:0x04ca, B:249:0x04da, B:250:0x04de, B:252:0x04e4, B:253:0x04ec, B:254:0x04ef, B:255:0x04f4, B:256:0x04f8, B:258:0x04fe, B:260:0x050e, B:262:0x0516, B:263:0x0519, B:265:0x051f, B:267:0x052b, B:268:0x052f, B:269:0x0532, B:270:0x0535, B:271:0x0541, B:273:0x0546, B:275:0x0550, B:276:0x0553, B:278:0x0559, B:280:0x0569, B:281:0x056d, B:283:0x0573, B:285:0x0583, B:286:0x0587, B:287:0x058a, B:288:0x058d, B:289:0x0593, B:291:0x0599, B:293:0x05ab, B:296:0x05b5, B:298:0x05bb, B:299:0x05be, B:301:0x05c4, B:303:0x05d0, B:304:0x05d4, B:305:0x05d7, B:311:0x05ec, B:312:0x05f8), top: B:322:0x006f, inners: #0, #1, #2, #4, #5, #6, #7, #8, #9 }] */
    /* JADX WARN: Removed duplicated region for block: B:62:0x013d A[Catch: CertPathReviewerException -> 0x05f9, TRY_LEAVE, TryCatch #3 {CertPathReviewerException -> 0x05f9, blocks: (B:17:0x006f, B:21:0x007f, B:23:0x008c, B:27:0x009c, B:28:0x00a7, B:30:0x00ad, B:32:0x00ce, B:33:0x00d6, B:35:0x00dc, B:37:0x00e1, B:38:0x00ed, B:42:0x00f9, B:45:0x0100, B:46:0x0109, B:48:0x010f, B:50:0x0119, B:53:0x0120, B:55:0x0124, B:95:0x0210, B:97:0x0216, B:98:0x0219, B:100:0x021f, B:102:0x022b, B:105:0x0233, B:106:0x0236, B:107:0x0239, B:109:0x023f, B:110:0x0248, B:112:0x024e, B:120:0x0271, B:121:0x027d, B:122:0x027e, B:124:0x0282, B:126:0x028a, B:127:0x028e, B:129:0x0294, B:132:0x02b6, B:134:0x02c0, B:135:0x02c5, B:136:0x02d1, B:137:0x02d2, B:138:0x02de, B:140:0x02e1, B:141:0x02ee, B:143:0x02f4, B:145:0x031a, B:147:0x0332, B:146:0x0329, B:148:0x0339, B:149:0x033f, B:151:0x0345, B:153:0x034d, B:164:0x0377, B:157:0x0355, B:158:0x0361, B:160:0x0363, B:161:0x0372, B:167:0x0380, B:178:0x039f, B:180:0x03a9, B:181:0x03ad, B:183:0x03b3, B:188:0x03c3, B:191:0x03d0, B:194:0x03dd, B:196:0x03e7, B:207:0x0425, B:199:0x03ef, B:200:0x03fd, B:201:0x03fe, B:202:0x040c, B:204:0x040e, B:205:0x041c, B:59:0x0133, B:60:0x0137, B:62:0x013d, B:64:0x0153, B:66:0x015d, B:67:0x0162, B:69:0x0168, B:70:0x0176, B:72:0x017c, B:74:0x0188, B:78:0x0195, B:79:0x019b, B:81:0x01a1, B:86:0x01ba, B:75:0x018b, B:77:0x018f, B:90:0x01f3, B:93:0x0203, B:94:0x020f, B:209:0x0434, B:210:0x0441, B:211:0x0442, B:215:0x0453, B:217:0x045d, B:218:0x0462, B:220:0x0468, B:223:0x0476, B:230:0x048b, B:309:0x05df, B:310:0x05eb, B:233:0x0496, B:234:0x04a2, B:235:0x04a3, B:237:0x04a9, B:239:0x04b1, B:241:0x04b7, B:244:0x04c1, B:245:0x04c4, B:247:0x04ca, B:249:0x04da, B:250:0x04de, B:252:0x04e4, B:253:0x04ec, B:254:0x04ef, B:255:0x04f4, B:256:0x04f8, B:258:0x04fe, B:260:0x050e, B:262:0x0516, B:263:0x0519, B:265:0x051f, B:267:0x052b, B:268:0x052f, B:269:0x0532, B:270:0x0535, B:271:0x0541, B:273:0x0546, B:275:0x0550, B:276:0x0553, B:278:0x0559, B:280:0x0569, B:281:0x056d, B:283:0x0573, B:285:0x0583, B:286:0x0587, B:287:0x058a, B:288:0x058d, B:289:0x0593, B:291:0x0599, B:293:0x05ab, B:296:0x05b5, B:298:0x05bb, B:299:0x05be, B:301:0x05c4, B:303:0x05d0, B:304:0x05d4, B:305:0x05d7, B:311:0x05ec, B:312:0x05f8), top: B:322:0x006f, inners: #0, #1, #2, #4, #5, #6, #7, #8, #9 }] */
    /* JADX WARN: Removed duplicated region for block: B:97:0x0216 A[Catch: CertPathReviewerException -> 0x05f9, TryCatch #3 {CertPathReviewerException -> 0x05f9, blocks: (B:17:0x006f, B:21:0x007f, B:23:0x008c, B:27:0x009c, B:28:0x00a7, B:30:0x00ad, B:32:0x00ce, B:33:0x00d6, B:35:0x00dc, B:37:0x00e1, B:38:0x00ed, B:42:0x00f9, B:45:0x0100, B:46:0x0109, B:48:0x010f, B:50:0x0119, B:53:0x0120, B:55:0x0124, B:95:0x0210, B:97:0x0216, B:98:0x0219, B:100:0x021f, B:102:0x022b, B:105:0x0233, B:106:0x0236, B:107:0x0239, B:109:0x023f, B:110:0x0248, B:112:0x024e, B:120:0x0271, B:121:0x027d, B:122:0x027e, B:124:0x0282, B:126:0x028a, B:127:0x028e, B:129:0x0294, B:132:0x02b6, B:134:0x02c0, B:135:0x02c5, B:136:0x02d1, B:137:0x02d2, B:138:0x02de, B:140:0x02e1, B:141:0x02ee, B:143:0x02f4, B:145:0x031a, B:147:0x0332, B:146:0x0329, B:148:0x0339, B:149:0x033f, B:151:0x0345, B:153:0x034d, B:164:0x0377, B:157:0x0355, B:158:0x0361, B:160:0x0363, B:161:0x0372, B:167:0x0380, B:178:0x039f, B:180:0x03a9, B:181:0x03ad, B:183:0x03b3, B:188:0x03c3, B:191:0x03d0, B:194:0x03dd, B:196:0x03e7, B:207:0x0425, B:199:0x03ef, B:200:0x03fd, B:201:0x03fe, B:202:0x040c, B:204:0x040e, B:205:0x041c, B:59:0x0133, B:60:0x0137, B:62:0x013d, B:64:0x0153, B:66:0x015d, B:67:0x0162, B:69:0x0168, B:70:0x0176, B:72:0x017c, B:74:0x0188, B:78:0x0195, B:79:0x019b, B:81:0x01a1, B:86:0x01ba, B:75:0x018b, B:77:0x018f, B:90:0x01f3, B:93:0x0203, B:94:0x020f, B:209:0x0434, B:210:0x0441, B:211:0x0442, B:215:0x0453, B:217:0x045d, B:218:0x0462, B:220:0x0468, B:223:0x0476, B:230:0x048b, B:309:0x05df, B:310:0x05eb, B:233:0x0496, B:234:0x04a2, B:235:0x04a3, B:237:0x04a9, B:239:0x04b1, B:241:0x04b7, B:244:0x04c1, B:245:0x04c4, B:247:0x04ca, B:249:0x04da, B:250:0x04de, B:252:0x04e4, B:253:0x04ec, B:254:0x04ef, B:255:0x04f4, B:256:0x04f8, B:258:0x04fe, B:260:0x050e, B:262:0x0516, B:263:0x0519, B:265:0x051f, B:267:0x052b, B:268:0x052f, B:269:0x0532, B:270:0x0535, B:271:0x0541, B:273:0x0546, B:275:0x0550, B:276:0x0553, B:278:0x0559, B:280:0x0569, B:281:0x056d, B:283:0x0573, B:285:0x0583, B:286:0x0587, B:287:0x058a, B:288:0x058d, B:289:0x0593, B:291:0x0599, B:293:0x05ab, B:296:0x05b5, B:298:0x05bb, B:299:0x05be, B:301:0x05c4, B:303:0x05d0, B:304:0x05d4, B:305:0x05d7, B:311:0x05ec, B:312:0x05f8), top: B:322:0x006f, inners: #0, #1, #2, #4, #5, #6, #7, #8, #9 }] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private void checkPolicy() {
        int i;
        int i2;
        PKIXPolicyNode pKIXPolicyNode;
        Set<String> set;
        String str;
        int i3;
        int i4;
        HashSet hashSet;
        String str2;
        int i5;
        int intValueExact;
        int intValueExact2;
        String str3;
        HashSet hashSet2;
        Enumeration objects;
        HashSet hashSet3;
        String str4;
        int i6;
        int i7;
        Set<String> criticalExtensionOIDs;
        String str5 = "CertPathReviewer.policyExtError";
        Set<String> initialPolicies = this.pkixParams.getInitialPolicies();
        int i8 = this.n + 1;
        ArrayList[] arrayListArr = new ArrayList[i8];
        for (int i9 = 0; i9 < i8; i9++) {
            arrayListArr[i9] = new ArrayList();
        }
        HashSet hashSet4 = new HashSet();
        hashSet4.add(RFC3280CertPathUtilities.ANY_POLICY);
        PKIXPolicyNode pKIXPolicyNode2 = new PKIXPolicyNode(new ArrayList(), 0, hashSet4, null, new HashSet(), RFC3280CertPathUtilities.ANY_POLICY, false);
        arrayListArr[0].add(pKIXPolicyNode2);
        if (this.pkixParams.isExplicitPolicyRequired()) {
            i2 = 0;
            i = 1;
        } else {
            i = 1;
            i2 = this.n + 1;
        }
        int i10 = this.pkixParams.isAnyPolicyInhibited() ? 0 : this.n + i;
        int i11 = this.pkixParams.isPolicyMappingInhibited() ? 0 : this.n + i;
        try {
            int size = this.certs.size() - i;
            PKIXPolicyNode pKIXPolicyNode3 = pKIXPolicyNode2;
            X509Certificate x509Certificate = null;
            HashSet hashSet5 = null;
            while (size >= 0) {
                int i12 = this.n - size;
                X509Certificate x509Certificate2 = (X509Certificate) this.certs.get(size);
                int i13 = i8;
                try {
                    ASN1Sequence aSN1Sequence = (ASN1Sequence) getExtensionValue(x509Certificate2, CERTIFICATE_POLICIES);
                    if (aSN1Sequence == null || pKIXPolicyNode3 == null) {
                        set = initialPolicies;
                        str = str5;
                        i3 = i10;
                        i4 = i11;
                        pKIXPolicyNode3 = pKIXPolicyNode3;
                    } else {
                        Enumeration objects2 = aSN1Sequence.getObjects();
                        set = initialPolicies;
                        HashSet hashSet6 = new HashSet();
                        while (objects2.hasMoreElements()) {
                            PolicyInformation policyInformation = PolicyInformation.getInstance(objects2.nextElement());
                            PKIXPolicyNode pKIXPolicyNode4 = pKIXPolicyNode3;
                            ASN1ObjectIdentifier policyIdentifier = policyInformation.getPolicyIdentifier();
                            String str6 = str5;
                            hashSet6.add(policyIdentifier.getId());
                            if (!RFC3280CertPathUtilities.ANY_POLICY.equals(policyIdentifier.getId())) {
                                try {
                                    Set qualifierSet = getQualifierSet(policyInformation.getPolicyQualifiers());
                                    if (!processCertD1i(i12, arrayListArr, policyIdentifier, qualifierSet)) {
                                        processCertD1ii(i12, arrayListArr, policyIdentifier, qualifierSet);
                                    }
                                } catch (CertPathValidatorException e) {
                                    throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.policyQualifierError"), e, this.certPath, size);
                                }
                            }
                            pKIXPolicyNode3 = pKIXPolicyNode4;
                            str5 = str6;
                        }
                        str = str5;
                        PKIXPolicyNode pKIXPolicyNode5 = pKIXPolicyNode3;
                        if (hashSet5 != null && !hashSet5.contains(RFC3280CertPathUtilities.ANY_POLICY)) {
                            hashSet2 = new HashSet();
                            for (Object obj : hashSet5) {
                                if (hashSet6.contains(obj)) {
                                    hashSet2.add(obj);
                                }
                            }
                            if (i10 <= 0) {
                                if (i12 < this.n && isSelfIssued(x509Certificate2)) {
                                }
                                i3 = i10;
                                i4 = i11;
                                hashSet3 = hashSet2;
                                pKIXPolicyNode3 = pKIXPolicyNode5;
                                for (i7 = i12 - 1; i7 >= 0; i7--) {
                                    ArrayList arrayList = arrayListArr[i7];
                                    for (int i14 = 0; i14 < arrayList.size(); i14++) {
                                        PKIXPolicyNode pKIXPolicyNode6 = (PKIXPolicyNode) arrayList.get(i14);
                                        if (!pKIXPolicyNode6.hasChildren()) {
                                            PKIXPolicyNode removePolicyNode = removePolicyNode(pKIXPolicyNode3, arrayListArr, pKIXPolicyNode6);
                                            pKIXPolicyNode3 = removePolicyNode;
                                            if (removePolicyNode == null) {
                                                break;
                                            }
                                        }
                                    }
                                }
                                criticalExtensionOIDs = x509Certificate2.getCriticalExtensionOIDs();
                                if (criticalExtensionOIDs != null) {
                                    boolean contains = criticalExtensionOIDs.contains(CERTIFICATE_POLICIES);
                                    ArrayList arrayList2 = arrayListArr[i12];
                                    for (int i15 = 0; i15 < arrayList2.size(); i15++) {
                                        ((PKIXPolicyNode) arrayList2.get(i15)).setCritical(contains);
                                    }
                                }
                                hashSet5 = hashSet3;
                            }
                            objects = aSN1Sequence.getObjects();
                            while (objects.hasMoreElements()) {
                                PolicyInformation policyInformation2 = PolicyInformation.getInstance(objects.nextElement());
                                if (RFC3280CertPathUtilities.ANY_POLICY.equals(policyInformation2.getPolicyIdentifier().getId())) {
                                    try {
                                        Set qualifierSet2 = getQualifierSet(policyInformation2.getPolicyQualifiers());
                                        ArrayList arrayList3 = arrayListArr[i12 - 1];
                                        hashSet3 = hashSet2;
                                        for (int i16 = 0; i16 < arrayList3.size(); i16++) {
                                            PKIXPolicyNode pKIXPolicyNode7 = (PKIXPolicyNode) arrayList3.get(i16);
                                            for (Object obj2 : pKIXPolicyNode7.getExpectedPolicies()) {
                                                ArrayList arrayList4 = arrayList3;
                                                int i17 = i10;
                                                if (obj2 instanceof String) {
                                                    str4 = (String) obj2;
                                                } else if (obj2 instanceof ASN1ObjectIdentifier) {
                                                    str4 = ((ASN1ObjectIdentifier) obj2).getId();
                                                } else {
                                                    arrayList3 = arrayList4;
                                                    i10 = i17;
                                                }
                                                Iterator children = pKIXPolicyNode7.getChildren();
                                                boolean z = false;
                                                while (children.hasNext()) {
                                                    Iterator it = children;
                                                    if (str4.equals(((PKIXPolicyNode) children.next()).getValidPolicy())) {
                                                        z = true;
                                                    }
                                                    children = it;
                                                }
                                                if (z) {
                                                    i6 = i11;
                                                } else {
                                                    HashSet hashSet7 = new HashSet();
                                                    hashSet7.add(str4);
                                                    i6 = i11;
                                                    PKIXPolicyNode pKIXPolicyNode8 = new PKIXPolicyNode(new ArrayList(), i12, hashSet7, pKIXPolicyNode7, qualifierSet2, str4, false);
                                                    pKIXPolicyNode7.addChild(pKIXPolicyNode8);
                                                    arrayListArr[i12].add(pKIXPolicyNode8);
                                                }
                                                arrayList3 = arrayList4;
                                                i10 = i17;
                                                i11 = i6;
                                            }
                                        }
                                        i3 = i10;
                                        i4 = i11;
                                        pKIXPolicyNode3 = pKIXPolicyNode5;
                                        while (i7 >= 0) {
                                        }
                                        criticalExtensionOIDs = x509Certificate2.getCriticalExtensionOIDs();
                                        if (criticalExtensionOIDs != null) {
                                        }
                                        hashSet5 = hashSet3;
                                    } catch (CertPathValidatorException e2) {
                                        throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.policyQualifierError"), e2, this.certPath, size);
                                    }
                                }
                            }
                            i3 = i10;
                            i4 = i11;
                            hashSet3 = hashSet2;
                            pKIXPolicyNode3 = pKIXPolicyNode5;
                            while (i7 >= 0) {
                            }
                            criticalExtensionOIDs = x509Certificate2.getCriticalExtensionOIDs();
                            if (criticalExtensionOIDs != null) {
                            }
                            hashSet5 = hashSet3;
                        }
                        hashSet2 = hashSet6;
                        if (i10 <= 0) {
                        }
                        objects = aSN1Sequence.getObjects();
                        while (objects.hasMoreElements()) {
                        }
                        i3 = i10;
                        i4 = i11;
                        hashSet3 = hashSet2;
                        pKIXPolicyNode3 = pKIXPolicyNode5;
                        while (i7 >= 0) {
                        }
                        criticalExtensionOIDs = x509Certificate2.getCriticalExtensionOIDs();
                        if (criticalExtensionOIDs != null) {
                        }
                        hashSet5 = hashSet3;
                    }
                    if (aSN1Sequence == null) {
                        pKIXPolicyNode3 = null;
                    }
                    if (i2 <= 0 && pKIXPolicyNode3 == null) {
                        throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.noValidPolicyTree"));
                    }
                    if (i12 != this.n) {
                        try {
                            ASN1Primitive extensionValue = getExtensionValue(x509Certificate2, POLICY_MAPPINGS);
                            if (extensionValue != null) {
                                ASN1Sequence aSN1Sequence2 = (ASN1Sequence) extensionValue;
                                int i18 = 0;
                                while (i18 < aSN1Sequence2.size()) {
                                    ASN1Sequence aSN1Sequence3 = (ASN1Sequence) aSN1Sequence2.getObjectAt(i18);
                                    ASN1ObjectIdentifier aSN1ObjectIdentifier = (ASN1ObjectIdentifier) aSN1Sequence3.getObjectAt(1);
                                    ASN1Sequence aSN1Sequence4 = aSN1Sequence2;
                                    if (RFC3280CertPathUtilities.ANY_POLICY.equals(((ASN1ObjectIdentifier) aSN1Sequence3.getObjectAt(0)).getId())) {
                                        throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.invalidPolicyMapping"), this.certPath, size);
                                    }
                                    if (RFC3280CertPathUtilities.ANY_POLICY.equals(aSN1ObjectIdentifier.getId())) {
                                        throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.invalidPolicyMapping"), this.certPath, size);
                                    }
                                    i18++;
                                    aSN1Sequence2 = aSN1Sequence4;
                                }
                            }
                            if (extensionValue != null) {
                                ASN1Sequence aSN1Sequence5 = (ASN1Sequence) extensionValue;
                                HashMap hashMap = new HashMap();
                                HashSet<String> hashSet8 = new HashSet();
                                int i19 = 0;
                                while (i19 < aSN1Sequence5.size()) {
                                    ASN1Sequence aSN1Sequence6 = (ASN1Sequence) aSN1Sequence5.getObjectAt(i19);
                                    ASN1Sequence aSN1Sequence7 = aSN1Sequence5;
                                    String id = ((ASN1ObjectIdentifier) aSN1Sequence6.getObjectAt(0)).getId();
                                    HashSet hashSet9 = hashSet5;
                                    String id2 = ((ASN1ObjectIdentifier) aSN1Sequence6.getObjectAt(1)).getId();
                                    if (hashMap.containsKey(id)) {
                                        ((Set) hashMap.get(id)).add(id2);
                                    } else {
                                        HashSet hashSet10 = new HashSet();
                                        hashSet10.add(id2);
                                        hashMap.put(id, hashSet10);
                                        hashSet8.add(id);
                                    }
                                    i19++;
                                    aSN1Sequence5 = aSN1Sequence7;
                                    hashSet5 = hashSet9;
                                }
                                hashSet = hashSet5;
                                for (String str7 : hashSet8) {
                                    if (i4 > 0) {
                                        try {
                                            try {
                                                prepareNextCertB1(i12, arrayListArr, str7, hashMap, x509Certificate2);
                                                str3 = str;
                                            } catch (CertPathValidatorException e3) {
                                                throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.policyQualifierError"), e3, this.certPath, size);
                                            }
                                        } catch (AnnotatedException e4) {
                                            throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, str), e4, this.certPath, size);
                                        }
                                    } else {
                                        str3 = str;
                                        if (i4 <= 0) {
                                            pKIXPolicyNode3 = prepareNextCertB2(i12, arrayListArr, str7, pKIXPolicyNode3);
                                        }
                                    }
                                    str = str3;
                                }
                            } else {
                                hashSet = hashSet5;
                            }
                            str2 = str;
                            if (isSelfIssued(x509Certificate2)) {
                                i5 = i3;
                                i11 = i4;
                            } else {
                                if (i2 != 0) {
                                    i2--;
                                }
                                i11 = i4 != 0 ? i4 - 1 : i4;
                                i5 = i3 != 0 ? i3 - 1 : i3;
                            }
                            try {
                                ASN1Sequence aSN1Sequence8 = (ASN1Sequence) getExtensionValue(x509Certificate2, POLICY_CONSTRAINTS);
                                if (aSN1Sequence8 != null) {
                                    Enumeration objects3 = aSN1Sequence8.getObjects();
                                    while (objects3.hasMoreElements()) {
                                        ASN1TaggedObject aSN1TaggedObject = (ASN1TaggedObject) objects3.nextElement();
                                        int tagNo = aSN1TaggedObject.getTagNo();
                                        if (tagNo == 0) {
                                            int intValueExact3 = ASN1Integer.getInstance(aSN1TaggedObject, false).intValueExact();
                                            if (intValueExact3 < i2) {
                                                i2 = intValueExact3;
                                            }
                                        } else if (tagNo == 1 && (intValueExact2 = ASN1Integer.getInstance(aSN1TaggedObject, false).intValueExact()) < i11) {
                                            i11 = intValueExact2;
                                        }
                                    }
                                }
                                try {
                                    ASN1Integer aSN1Integer = (ASN1Integer) getExtensionValue(x509Certificate2, INHIBIT_ANY_POLICY);
                                    if (aSN1Integer != null && (intValueExact = aSN1Integer.intValueExact()) < i5) {
                                        i5 = intValueExact;
                                    }
                                } catch (AnnotatedException unused) {
                                    throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.policyInhibitExtError"), this.certPath, size);
                                }
                            } catch (AnnotatedException unused2) {
                                throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.policyConstExtError"), this.certPath, size);
                            }
                        } catch (AnnotatedException e5) {
                            throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.policyMapExtError"), e5, this.certPath, size);
                        }
                    } else {
                        hashSet = hashSet5;
                        str2 = str;
                        i5 = i3;
                        i11 = i4;
                    }
                    size--;
                    x509Certificate = x509Certificate2;
                    str5 = str2;
                    hashSet5 = hashSet;
                    i8 = i13;
                    i10 = i5;
                    initialPolicies = set;
                } catch (AnnotatedException e6) {
                    throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, str5), e6, this.certPath, size);
                }
            }
            Set<String> set2 = initialPolicies;
            int i20 = i8;
            PKIXPolicyNode pKIXPolicyNode9 = pKIXPolicyNode3;
            if (!isSelfIssued(x509Certificate) && i2 > 0) {
                i2--;
            }
            try {
                ASN1Sequence aSN1Sequence9 = (ASN1Sequence) getExtensionValue(x509Certificate, POLICY_CONSTRAINTS);
                if (aSN1Sequence9 != null) {
                    Enumeration objects4 = aSN1Sequence9.getObjects();
                    int i21 = i2;
                    while (objects4.hasMoreElements()) {
                        ASN1TaggedObject aSN1TaggedObject2 = (ASN1TaggedObject) objects4.nextElement();
                        if (aSN1TaggedObject2.getTagNo() == 0 && ASN1Integer.getInstance(aSN1TaggedObject2, false).intValueExact() == 0) {
                            i21 = 0;
                        }
                    }
                    i2 = i21;
                }
                if (pKIXPolicyNode9 == null) {
                    if (this.pkixParams.isExplicitPolicyRequired()) {
                        throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.explicitPolicy"), this.certPath, size);
                    }
                    pKIXPolicyNode = null;
                } else if (isAnyPolicy(set2)) {
                    if (this.pkixParams.isExplicitPolicyRequired()) {
                        if (hashSet5.isEmpty()) {
                            throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.explicitPolicy"), this.certPath, size);
                        }
                        HashSet<PKIXPolicyNode> hashSet11 = new HashSet();
                        int i22 = 0;
                        while (true) {
                            int i23 = i20;
                            if (i22 >= i23) {
                                break;
                            }
                            ArrayList arrayList5 = arrayListArr[i22];
                            for (int i24 = 0; i24 < arrayList5.size(); i24++) {
                                PKIXPolicyNode pKIXPolicyNode10 = (PKIXPolicyNode) arrayList5.get(i24);
                                if (RFC3280CertPathUtilities.ANY_POLICY.equals(pKIXPolicyNode10.getValidPolicy())) {
                                    Iterator children2 = pKIXPolicyNode10.getChildren();
                                    while (children2.hasNext()) {
                                        hashSet11.add(children2.next());
                                    }
                                }
                            }
                            i22++;
                            i20 = i23;
                        }
                        for (PKIXPolicyNode pKIXPolicyNode11 : hashSet11) {
                            hashSet5.contains(pKIXPolicyNode11.getValidPolicy());
                        }
                        if (pKIXPolicyNode9 != null) {
                            pKIXPolicyNode = pKIXPolicyNode9;
                            for (int i25 = this.n - 1; i25 >= 0; i25--) {
                                ArrayList arrayList6 = arrayListArr[i25];
                                for (int i26 = 0; i26 < arrayList6.size(); i26++) {
                                    PKIXPolicyNode pKIXPolicyNode12 = (PKIXPolicyNode) arrayList6.get(i26);
                                    if (!pKIXPolicyNode12.hasChildren()) {
                                        pKIXPolicyNode = removePolicyNode(pKIXPolicyNode, arrayListArr, pKIXPolicyNode12);
                                    }
                                }
                            }
                        }
                    }
                    pKIXPolicyNode = pKIXPolicyNode9;
                } else {
                    HashSet<PKIXPolicyNode> hashSet12 = new HashSet();
                    for (int i27 = 0; i27 < i20; i27++) {
                        ArrayList arrayList7 = arrayListArr[i27];
                        for (int i28 = 0; i28 < arrayList7.size(); i28++) {
                            PKIXPolicyNode pKIXPolicyNode13 = (PKIXPolicyNode) arrayList7.get(i28);
                            if (RFC3280CertPathUtilities.ANY_POLICY.equals(pKIXPolicyNode13.getValidPolicy())) {
                                Iterator children3 = pKIXPolicyNode13.getChildren();
                                while (children3.hasNext()) {
                                    PKIXPolicyNode pKIXPolicyNode14 = (PKIXPolicyNode) children3.next();
                                    if (!RFC3280CertPathUtilities.ANY_POLICY.equals(pKIXPolicyNode14.getValidPolicy())) {
                                        hashSet12.add(pKIXPolicyNode14);
                                    }
                                }
                            }
                        }
                    }
                    pKIXPolicyNode = pKIXPolicyNode9;
                    for (PKIXPolicyNode pKIXPolicyNode15 : hashSet12) {
                        Set<String> set3 = set2;
                        if (!set3.contains(pKIXPolicyNode15.getValidPolicy())) {
                            pKIXPolicyNode = removePolicyNode(pKIXPolicyNode, arrayListArr, pKIXPolicyNode15);
                        }
                        set2 = set3;
                    }
                    if (pKIXPolicyNode != null) {
                        for (int i29 = this.n - 1; i29 >= 0; i29--) {
                            ArrayList arrayList8 = arrayListArr[i29];
                            for (int i30 = 0; i30 < arrayList8.size(); i30++) {
                                PKIXPolicyNode pKIXPolicyNode16 = (PKIXPolicyNode) arrayList8.get(i30);
                                if (!pKIXPolicyNode16.hasChildren()) {
                                    pKIXPolicyNode = removePolicyNode(pKIXPolicyNode, arrayListArr, pKIXPolicyNode16);
                                }
                            }
                        }
                    }
                }
                if (i2 <= 0 && pKIXPolicyNode == null) {
                    throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.invalidPolicy"));
                }
            } catch (AnnotatedException unused3) {
                throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.policyConstExtError"), this.certPath, size);
            }
        } catch (CertPathReviewerException e7) {
            addError(e7.getErrorMessage(), e7.getIndex());
        }
    }

    /* JADX WARN: Can't wrap try/catch for region: R(15:(2:91|92)|(3:(15:94|95|96|(11:98|99|(2:102|100)|103|104|(2:107|105)|108|109|110|111|112)|119|99|(1:100)|103|104|(1:105)|108|109|110|111|112)|111|112)|122|95|96|(0)|119|99|(1:100)|103|104|(1:105)|108|109|110) */
    /* JADX WARN: Can't wrap try/catch for region: R(18:91|92|(15:94|95|96|(11:98|99|(2:102|100)|103|104|(2:107|105)|108|109|110|111|112)|119|99|(1:100)|103|104|(1:105)|108|109|110|111|112)|122|95|96|(0)|119|99|(1:100)|103|104|(1:105)|108|109|110|111|112) */
    /* JADX WARN: Can't wrap try/catch for region: R(19:30|(2:137|138)(2:32|(2:130|131)(20:34|(2:38|(17:40|41|42|43|44|(18:91|92|(15:94|95|96|(11:98|99|(2:102|100)|103|104|(2:107|105)|108|109|110|111|112)|119|99|(1:100)|103|104|(1:105)|108|109|110|111|112)|122|95|96|(0)|119|99|(1:100)|103|104|(1:105)|108|109|110|111|112)(1:46)|(1:90)(1:50)|51|(1:89)(7:53|(1:57)|58|59|(2:61|(1:63))(1:85)|64|(9:66|(1:83)|70|71|72|74|75|77|78))|84|70|71|72|74|75|77|78))|129|41|42|43|44|(0)(0)|(1:48)|90|51|(0)(0)|84|70|71|72|74|75|77|78))|132|42|43|44|(0)(0)|(0)|90|51|(0)(0)|84|70|71|72|74|75|77|78) */
    /* JADX WARN: Code restructure failed: missing block: B:114:0x0324, code lost:
        r0 = e;
     */
    /* JADX WARN: Code restructure failed: missing block: B:115:0x0325, code lost:
        r13 = r3;
        r15 = r4;
        r11 = r5;
        r16 = r6;
        r12 = r7;
        r18 = r9;
     */
    /* JADX WARN: Code restructure failed: missing block: B:152:0x03e4, code lost:
        r6 = r16;
     */
    /* JADX WARN: Code restructure failed: missing block: B:153:0x03e6, code lost:
        addError(new org.bouncycastle.i18n.ErrorBundle(org.bouncycastle.x509.PKIXCertPathReviewer.RESOURCE_NAME, "CertPathReviewer.pubKeyError"), r11);
     */
    /* JADX WARN: Code restructure failed: missing block: B:83:0x0256, code lost:
        r1 = new java.lang.Object[r13];
        r1[r12] = new org.bouncycastle.i18n.filter.TrustedInput(r3.getNotAfter());
        r0 = new org.bouncycastle.i18n.ErrorBundle(org.bouncycastle.x509.PKIXCertPathReviewer.RESOURCE_NAME, "CertPathReviewer.certificateExpired", r1);
     */
    /* JADX WARN: Code restructure failed: missing block: B:84:0x026b, code lost:
        r1 = new java.lang.Object[r13];
        r1[r12] = new org.bouncycastle.i18n.filter.TrustedInput(r3.getNotBefore());
        r0 = new org.bouncycastle.i18n.ErrorBundle(org.bouncycastle.x509.PKIXCertPathReviewer.RESOURCE_NAME, "CertPathReviewer.certificateNotYetValid", r1);
     */
    /* JADX WARN: Code restructure failed: missing block: B:85:0x027f, code lost:
        addError(r0, r5);
     */
    /* JADX WARN: Code restructure failed: missing block: B:98:0x02b1, code lost:
        addError(new org.bouncycastle.i18n.ErrorBundle(org.bouncycastle.x509.PKIXCertPathReviewer.RESOURCE_NAME, "CertPathReviewer.crlAuthInfoAccError"), r5);
     */
    /* JADX WARN: Removed duplicated region for block: B:103:0x02ce A[LOOP:1: B:101:0x02c8->B:103:0x02ce, LOOP_END] */
    /* JADX WARN: Removed duplicated region for block: B:107:0x02f2 A[LOOP:2: B:105:0x02ec->B:107:0x02f2, LOOP_END] */
    /* JADX WARN: Removed duplicated region for block: B:117:0x0335  */
    /* JADX WARN: Removed duplicated region for block: B:119:0x033f  */
    /* JADX WARN: Removed duplicated region for block: B:125:0x036f  */
    /* JADX WARN: Removed duplicated region for block: B:146:0x03cd  */
    /* JADX WARN: Removed duplicated region for block: B:173:0x028a A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:32:0x00f9  */
    /* JADX WARN: Removed duplicated region for block: B:46:0x0140  */
    /* JADX WARN: Removed duplicated region for block: B:48:0x0143  */
    /* JADX WARN: Removed duplicated region for block: B:55:0x0168  */
    /* JADX WARN: Removed duplicated region for block: B:58:0x0178  */
    /* JADX WARN: Removed duplicated region for block: B:96:0x02ac A[Catch: AnnotatedException -> 0x02b1, TRY_LEAVE, TryCatch #18 {AnnotatedException -> 0x02b1, blocks: (B:94:0x02a4, B:96:0x02ac), top: B:179:0x02a4 }] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private void checkSignatures() {
        TrustAnchor trustAnchor;
        TrustAnchor trustAnchor2;
        X500Principal x500Principal;
        X509Certificate x509Certificate;
        PublicKey publicKey;
        int size;
        ErrorBundle errorBundle;
        CRLDistPoint cRLDistPoint;
        AuthorityInformationAccess authorityInformationAccess;
        Iterator it;
        Iterator it2;
        X509Certificate x509Certificate2;
        int i;
        int i2;
        PublicKey publicKey2;
        X500Principal x500Principal2;
        TrustAnchor trustAnchor3;
        ASN1Primitive extensionValue;
        ASN1Primitive extensionValue2;
        AuthorityKeyIdentifier authorityKeyIdentifier;
        GeneralNames authorityCertIssuer;
        boolean[] keyUsage;
        X509Certificate x509Certificate3;
        Collection trustAnchors;
        char c = 2;
        char c2 = 0;
        int i3 = 1;
        addNotification(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.certPathValidDate", new Object[]{new TrustedInput(this.validDate), new TrustedInput(this.currentDate)}));
        try {
            List list = this.certs;
            x509Certificate3 = (X509Certificate) list.get(list.size() - 1);
            trustAnchors = getTrustAnchors(x509Certificate3, this.pkixParams.getTrustAnchors());
        } catch (CertPathReviewerException e) {
            e = e;
            trustAnchor = null;
        } catch (Throwable th) {
            th = th;
            trustAnchor = null;
        }
        if (trustAnchors.size() > 1) {
            addError(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.conflictingTrustAnchors", new Object[]{Integers.valueOf(trustAnchors.size()), new UntrustedInput(x509Certificate3.getIssuerX500Principal())}));
        } else if (!trustAnchors.isEmpty()) {
            trustAnchor = (TrustAnchor) trustAnchors.iterator().next();
            try {
                try {
                    CertPathValidatorUtilities.verifyX509Certificate(x509Certificate3, trustAnchor.getTrustedCert() != null ? trustAnchor.getTrustedCert().getPublicKey() : trustAnchor.getCAPublicKey(), this.pkixParams.getSigProvider());
                } catch (SignatureException unused) {
                    addError(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.trustButInvalidCert"));
                } catch (Exception unused2) {
                }
            } catch (CertPathReviewerException e2) {
                e = e2;
                addError(e.getErrorMessage());
                trustAnchor2 = trustAnchor;
                if (trustAnchor2 == null) {
                }
                if (trustAnchor2 == null) {
                }
                X509Certificate x509Certificate4 = x509Certificate;
                X500Principal x500Principal3 = x500Principal;
                PublicKey publicKey3 = publicKey;
                size = this.certs.size() - 1;
                while (size >= 0) {
                }
                this.trustAnchor = trustAnchor2;
                this.subjectPublicKey = publicKey3;
            } catch (Throwable th2) {
                th = th2;
                addError(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.unknown", new Object[]{new UntrustedInput(th.getMessage()), new UntrustedInput(th)}));
                trustAnchor2 = trustAnchor;
                if (trustAnchor2 == null) {
                }
                if (trustAnchor2 == null) {
                }
                X509Certificate x509Certificate42 = x509Certificate;
                X500Principal x500Principal32 = x500Principal;
                PublicKey publicKey32 = publicKey;
                size = this.certs.size() - 1;
                while (size >= 0) {
                }
                this.trustAnchor = trustAnchor2;
                this.subjectPublicKey = publicKey32;
            }
            trustAnchor2 = trustAnchor;
            if (trustAnchor2 == null) {
                X509Certificate trustedCert = trustAnchor2.getTrustedCert();
                try {
                    x500Principal = trustedCert != null ? getSubjectPrincipal(trustedCert) : new X500Principal(trustAnchor2.getCAName());
                } catch (IllegalArgumentException unused3) {
                    addError(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.trustDNInvalid", new Object[]{new UntrustedInput(trustAnchor2.getCAName())}));
                    x500Principal = null;
                }
                if (trustedCert != null && (keyUsage = trustedCert.getKeyUsage()) != null && (keyUsage.length <= 5 || !keyUsage[5])) {
                    addNotification(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.trustKeyUsage"));
                }
            } else {
                x500Principal = null;
            }
            if (trustAnchor2 == null) {
                x509Certificate = trustAnchor2.getTrustedCert();
                publicKey = x509Certificate != null ? x509Certificate.getPublicKey() : trustAnchor2.getCAPublicKey();
                try {
                    AlgorithmIdentifier algorithmIdentifier = getAlgorithmIdentifier(publicKey);
                    algorithmIdentifier.getAlgorithm();
                    algorithmIdentifier.getParameters();
                } catch (CertPathValidatorException unused4) {
                    addError(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.trustPubKeyError"));
                }
            } else {
                x509Certificate = null;
                publicKey = null;
            }
            X509Certificate x509Certificate422 = x509Certificate;
            X500Principal x500Principal322 = x500Principal;
            PublicKey publicKey322 = publicKey;
            size = this.certs.size() - 1;
            while (size >= 0) {
                int i4 = this.n - size;
                X509Certificate x509Certificate5 = (X509Certificate) this.certs.get(size);
                if (publicKey322 != null) {
                    try {
                        CertPathValidatorUtilities.verifyX509Certificate(x509Certificate5, publicKey322, this.pkixParams.getSigProvider());
                    } catch (GeneralSecurityException e3) {
                        Object[] objArr = new Object[3];
                        objArr[c2] = e3.getMessage();
                        objArr[i3] = e3;
                        objArr[c] = e3.getClass().getName();
                        errorBundle = new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.signatureNotVerified", objArr);
                        addError(errorBundle, size);
                        x509Certificate5.checkValidity(this.validDate);
                        if (this.pkixParams.isRevocationEnabled()) {
                        }
                        if (x500Principal2 == null) {
                        }
                        if (i != this.n) {
                        }
                        x500Principal322 = x509Certificate2.getSubjectX500Principal();
                        publicKey322 = getNextWorkingKey(this.certs, i2);
                        AlgorithmIdentifier algorithmIdentifier2 = getAlgorithmIdentifier(publicKey322);
                        algorithmIdentifier2.getAlgorithm();
                        algorithmIdentifier2.getParameters();
                        size = i2 - 1;
                        x509Certificate422 = x509Certificate2;
                        trustAnchor2 = trustAnchor3;
                        c = 2;
                        c2 = 0;
                        i3 = 1;
                    }
                } else if (isSelfIssued(x509Certificate5)) {
                    try {
                        CertPathValidatorUtilities.verifyX509Certificate(x509Certificate5, x509Certificate5.getPublicKey(), this.pkixParams.getSigProvider());
                        addError(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.rootKeyIsValidButNotATrustAnchor"), size);
                    } catch (GeneralSecurityException e4) {
                        Object[] objArr2 = new Object[3];
                        objArr2[c2] = e4.getMessage();
                        objArr2[i3] = e4;
                        objArr2[c] = e4.getClass().getName();
                        errorBundle = new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.signatureNotVerified", objArr2);
                        addError(errorBundle, size);
                        x509Certificate5.checkValidity(this.validDate);
                        if (this.pkixParams.isRevocationEnabled()) {
                        }
                        if (x500Principal2 == null) {
                        }
                        if (i != this.n) {
                        }
                        x500Principal322 = x509Certificate2.getSubjectX500Principal();
                        publicKey322 = getNextWorkingKey(this.certs, i2);
                        AlgorithmIdentifier algorithmIdentifier22 = getAlgorithmIdentifier(publicKey322);
                        algorithmIdentifier22.getAlgorithm();
                        algorithmIdentifier22.getParameters();
                        size = i2 - 1;
                        x509Certificate422 = x509Certificate2;
                        trustAnchor2 = trustAnchor3;
                        c = 2;
                        c2 = 0;
                        i3 = 1;
                    }
                } else {
                    ErrorBundle errorBundle2 = new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.NoIssuerPublicKey");
                    byte[] extensionValue3 = x509Certificate5.getExtensionValue(Extension.authorityKeyIdentifier.getId());
                    if (extensionValue3 != null && (authorityCertIssuer = (authorityKeyIdentifier = AuthorityKeyIdentifier.getInstance(DEROctetString.getInstance(extensionValue3).getOctets())).getAuthorityCertIssuer()) != null) {
                        GeneralName generalName = authorityCertIssuer.getNames()[c2];
                        BigInteger authorityCertSerialNumber = authorityKeyIdentifier.getAuthorityCertSerialNumber();
                        if (authorityCertSerialNumber != null) {
                            Object[] objArr3 = new Object[7];
                            objArr3[c2] = new LocaleString(RESOURCE_NAME, "missingIssuer");
                            objArr3[i3] = " \"";
                            objArr3[2] = generalName;
                            objArr3[3] = "\" ";
                            objArr3[4] = new LocaleString(RESOURCE_NAME, "missingSerial");
                            objArr3[5] = StringUtils.SPACE;
                            objArr3[6] = authorityCertSerialNumber;
                            errorBundle2.setExtraArguments(objArr3);
                            addError(errorBundle2, size);
                            x509Certificate5.checkValidity(this.validDate);
                            if (this.pkixParams.isRevocationEnabled()) {
                                try {
                                    extensionValue2 = getExtensionValue(x509Certificate5, CRL_DIST_POINTS);
                                } catch (AnnotatedException unused5) {
                                    addError(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.crlDistPtExtError"), size);
                                }
                                try {
                                    if (extensionValue2 != null) {
                                        cRLDistPoint = CRLDistPoint.getInstance(extensionValue2);
                                        extensionValue = getExtensionValue(x509Certificate5, AUTH_INFO_ACCESS);
                                        if (extensionValue != null) {
                                            authorityInformationAccess = AuthorityInformationAccess.getInstance(extensionValue);
                                            Vector cRLDistUrls = getCRLDistUrls(cRLDistPoint);
                                            Vector oCSPUrls = getOCSPUrls(authorityInformationAccess);
                                            it = cRLDistUrls.iterator();
                                            while (it.hasNext()) {
                                                Object[] objArr4 = new Object[i3];
                                                objArr4[c2] = new UntrustedUrlInput(it.next());
                                                addNotification(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.crlDistPoint", objArr4), size);
                                                i3 = 1;
                                            }
                                            it2 = oCSPUrls.iterator();
                                            while (it2.hasNext()) {
                                                Object[] objArr5 = new Object[1];
                                                objArr5[c2] = new UntrustedUrlInput(it2.next());
                                                addNotification(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.ocspLocation", objArr5), size);
                                            }
                                            x509Certificate2 = x509Certificate5;
                                            i = i4;
                                            i2 = size;
                                            X509Certificate x509Certificate6 = x509Certificate422;
                                            publicKey2 = publicKey322;
                                            x500Principal2 = x500Principal322;
                                            trustAnchor3 = trustAnchor2;
                                            checkRevocation(this.pkixParams, x509Certificate5, this.validDate, x509Certificate6, publicKey322, cRLDistUrls, oCSPUrls, i2);
                                        }
                                        authorityInformationAccess = null;
                                        Vector cRLDistUrls2 = getCRLDistUrls(cRLDistPoint);
                                        Vector oCSPUrls2 = getOCSPUrls(authorityInformationAccess);
                                        it = cRLDistUrls2.iterator();
                                        while (it.hasNext()) {
                                        }
                                        it2 = oCSPUrls2.iterator();
                                        while (it2.hasNext()) {
                                        }
                                        x509Certificate2 = x509Certificate5;
                                        i = i4;
                                        i2 = size;
                                        X509Certificate x509Certificate62 = x509Certificate422;
                                        publicKey2 = publicKey322;
                                        x500Principal2 = x500Principal322;
                                        trustAnchor3 = trustAnchor2;
                                        checkRevocation(this.pkixParams, x509Certificate5, this.validDate, x509Certificate62, publicKey322, cRLDistUrls2, oCSPUrls2, i2);
                                    }
                                    checkRevocation(this.pkixParams, x509Certificate5, this.validDate, x509Certificate62, publicKey322, cRLDistUrls2, oCSPUrls2, i2);
                                } catch (CertPathReviewerException e5) {
                                    e = e5;
                                    addError(e.getErrorMessage(), i2);
                                    if (x500Principal2 == null) {
                                    }
                                    if (i != this.n) {
                                    }
                                    x500Principal322 = x509Certificate2.getSubjectX500Principal();
                                    publicKey322 = getNextWorkingKey(this.certs, i2);
                                    AlgorithmIdentifier algorithmIdentifier222 = getAlgorithmIdentifier(publicKey322);
                                    algorithmIdentifier222.getAlgorithm();
                                    algorithmIdentifier222.getParameters();
                                    size = i2 - 1;
                                    x509Certificate422 = x509Certificate2;
                                    trustAnchor2 = trustAnchor3;
                                    c = 2;
                                    c2 = 0;
                                    i3 = 1;
                                }
                                cRLDistPoint = null;
                                extensionValue = getExtensionValue(x509Certificate5, AUTH_INFO_ACCESS);
                                if (extensionValue != null) {
                                }
                                authorityInformationAccess = null;
                                Vector cRLDistUrls22 = getCRLDistUrls(cRLDistPoint);
                                Vector oCSPUrls22 = getOCSPUrls(authorityInformationAccess);
                                it = cRLDistUrls22.iterator();
                                while (it.hasNext()) {
                                }
                                it2 = oCSPUrls22.iterator();
                                while (it2.hasNext()) {
                                }
                                x509Certificate2 = x509Certificate5;
                                i = i4;
                                i2 = size;
                                X509Certificate x509Certificate622 = x509Certificate422;
                                publicKey2 = publicKey322;
                                x500Principal2 = x500Principal322;
                                trustAnchor3 = trustAnchor2;
                            } else {
                                x509Certificate2 = x509Certificate5;
                                i = i4;
                                i2 = size;
                                publicKey2 = publicKey322;
                                x500Principal2 = x500Principal322;
                                trustAnchor3 = trustAnchor2;
                            }
                            if (x500Principal2 == null && !x509Certificate2.getIssuerX500Principal().equals(x500Principal2)) {
                                addError(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.certWrongIssuer", new Object[]{x500Principal2.getName(), x509Certificate2.getIssuerX500Principal().getName()}), i2);
                            }
                            if (i != this.n) {
                                if (x509Certificate2 != null && x509Certificate2.getVersion() == 1) {
                                    addError(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.noCACert"), i2);
                                }
                                try {
                                    BasicConstraints basicConstraints = BasicConstraints.getInstance(getExtensionValue(x509Certificate2, BASIC_CONSTRAINTS));
                                    if (basicConstraints == null) {
                                        addError(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.noBasicConstraints"), i2);
                                    } else if (!basicConstraints.isCA()) {
                                        addError(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.noCACert"), i2);
                                    }
                                } catch (AnnotatedException unused6) {
                                    addError(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.errorProcesingBC"), i2);
                                }
                                boolean[] keyUsage2 = x509Certificate2.getKeyUsage();
                                if (keyUsage2 != null) {
                                    if (keyUsage2.length <= 5 || !keyUsage2[5]) {
                                        addError(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.noCertSign"), i2);
                                    }
                                    x500Principal322 = x509Certificate2.getSubjectX500Principal();
                                    publicKey322 = getNextWorkingKey(this.certs, i2);
                                    AlgorithmIdentifier algorithmIdentifier2222 = getAlgorithmIdentifier(publicKey322);
                                    algorithmIdentifier2222.getAlgorithm();
                                    algorithmIdentifier2222.getParameters();
                                    size = i2 - 1;
                                    x509Certificate422 = x509Certificate2;
                                    trustAnchor2 = trustAnchor3;
                                    c = 2;
                                    c2 = 0;
                                    i3 = 1;
                                }
                            }
                            x500Principal322 = x509Certificate2.getSubjectX500Principal();
                            publicKey322 = getNextWorkingKey(this.certs, i2);
                            AlgorithmIdentifier algorithmIdentifier22222 = getAlgorithmIdentifier(publicKey322);
                            algorithmIdentifier22222.getAlgorithm();
                            algorithmIdentifier22222.getParameters();
                            size = i2 - 1;
                            x509Certificate422 = x509Certificate2;
                            trustAnchor2 = trustAnchor3;
                            c = 2;
                            c2 = 0;
                            i3 = 1;
                        }
                    }
                    addError(errorBundle2, size);
                    x509Certificate5.checkValidity(this.validDate);
                    if (this.pkixParams.isRevocationEnabled()) {
                    }
                    if (x500Principal2 == null) {
                    }
                    if (i != this.n) {
                    }
                    x500Principal322 = x509Certificate2.getSubjectX500Principal();
                    publicKey322 = getNextWorkingKey(this.certs, i2);
                    AlgorithmIdentifier algorithmIdentifier222222 = getAlgorithmIdentifier(publicKey322);
                    algorithmIdentifier222222.getAlgorithm();
                    algorithmIdentifier222222.getParameters();
                    size = i2 - 1;
                    x509Certificate422 = x509Certificate2;
                    trustAnchor2 = trustAnchor3;
                    c = 2;
                    c2 = 0;
                    i3 = 1;
                }
                x509Certificate5.checkValidity(this.validDate);
                if (this.pkixParams.isRevocationEnabled()) {
                }
                if (x500Principal2 == null) {
                }
                if (i != this.n) {
                }
                x500Principal322 = x509Certificate2.getSubjectX500Principal();
                publicKey322 = getNextWorkingKey(this.certs, i2);
                AlgorithmIdentifier algorithmIdentifier2222222 = getAlgorithmIdentifier(publicKey322);
                algorithmIdentifier2222222.getAlgorithm();
                algorithmIdentifier2222222.getParameters();
                size = i2 - 1;
                x509Certificate422 = x509Certificate2;
                trustAnchor2 = trustAnchor3;
                c = 2;
                c2 = 0;
                i3 = 1;
            }
            this.trustAnchor = trustAnchor2;
            this.subjectPublicKey = publicKey322;
        } else {
            addError(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.noTrustAnchorFound", new Object[]{new UntrustedInput(x509Certificate3.getIssuerX500Principal()), Integers.valueOf(this.pkixParams.getTrustAnchors().size())}));
        }
        trustAnchor = null;
        trustAnchor2 = trustAnchor;
        if (trustAnchor2 == null) {
        }
        if (trustAnchor2 == null) {
        }
        X509Certificate x509Certificate4222 = x509Certificate;
        X500Principal x500Principal3222 = x500Principal;
        PublicKey publicKey3222 = publicKey;
        size = this.certs.size() - 1;
        while (size >= 0) {
        }
        this.trustAnchor = trustAnchor2;
        this.subjectPublicKey = publicKey3222;
    }

    private X509CRL getCRL(String str) throws CertPathReviewerException {
        try {
            URL url = new URL(str);
            if (!url.getProtocol().equals("http") && !url.getProtocol().equals("https")) {
                return null;
            }
            HttpURLConnection httpURLConnection = (HttpURLConnection) url.openConnection();
            httpURLConnection.setUseCaches(false);
            httpURLConnection.setDoInput(true);
            httpURLConnection.connect();
            if (httpURLConnection.getResponseCode() == 200) {
                return (X509CRL) CertificateFactory.getInstance("X.509", BouncyCastleProvider.PROVIDER_NAME).generateCRL(httpURLConnection.getInputStream());
            }
            throw new Exception(httpURLConnection.getResponseMessage());
        } catch (Exception e) {
            throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.loadCrlDistPointError", new Object[]{new UntrustedInput(str), e.getMessage(), e, e.getClass().getName()}));
        }
    }

    private boolean processQcStatements(X509Certificate x509Certificate, int i) {
        ErrorBundle errorBundle;
        try {
            ASN1Sequence aSN1Sequence = (ASN1Sequence) getExtensionValue(x509Certificate, QC_STATEMENT);
            boolean z = false;
            for (int i2 = 0; i2 < aSN1Sequence.size(); i2++) {
                QCStatement qCStatement = QCStatement.getInstance(aSN1Sequence.getObjectAt(i2));
                if (QCStatement.id_etsi_qcs_QcCompliance.equals((ASN1Primitive) qCStatement.getStatementId())) {
                    errorBundle = new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.QcEuCompliance");
                } else {
                    if (!QCStatement.id_qcs_pkixQCSyntax_v1.equals((ASN1Primitive) qCStatement.getStatementId())) {
                        if (QCStatement.id_etsi_qcs_QcSSCD.equals((ASN1Primitive) qCStatement.getStatementId())) {
                            errorBundle = new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.QcSSCD");
                        } else if (QCStatement.id_etsi_qcs_LimiteValue.equals((ASN1Primitive) qCStatement.getStatementId())) {
                            MonetaryValue monetaryValue = MonetaryValue.getInstance(qCStatement.getStatementInfo());
                            monetaryValue.getCurrency();
                            double doubleValue = monetaryValue.getAmount().doubleValue() * Math.pow(10.0d, monetaryValue.getExponent().doubleValue());
                            addNotification(monetaryValue.getCurrency().isAlphabetic() ? new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.QcLimitValueAlpha", new Object[]{monetaryValue.getCurrency().getAlphabetic(), new TrustedInput(new Double(doubleValue)), monetaryValue}) : new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.QcLimitValueNum", new Object[]{Integers.valueOf(monetaryValue.getCurrency().getNumeric()), new TrustedInput(new Double(doubleValue)), monetaryValue}), i);
                        } else {
                            addNotification(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.QcUnknownStatement", new Object[]{qCStatement.getStatementId(), new UntrustedInput(qCStatement)}), i);
                            z = true;
                        }
                    }
                }
                addNotification(errorBundle, i);
            }
            return true ^ z;
        } catch (AnnotatedException unused) {
            addError(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.QcStatementExtError"), i);
            return false;
        }
    }

    protected void addError(ErrorBundle errorBundle) {
        this.errors[0].add(errorBundle);
    }

    protected void addError(ErrorBundle errorBundle, int i) {
        if (i < -1 || i >= this.n) {
            throw new IndexOutOfBoundsException();
        }
        this.errors[i + 1].add(errorBundle);
    }

    protected void addNotification(ErrorBundle errorBundle) {
        this.notifications[0].add(errorBundle);
    }

    protected void addNotification(ErrorBundle errorBundle, int i) {
        if (i < -1 || i >= this.n) {
            throw new IndexOutOfBoundsException();
        }
        this.notifications[i + 1].add(errorBundle);
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: Unreachable block: B:39:0x0165
        	at jadx.core.dex.visitors.blocks.BlockProcessor.checkForUnreachableBlocks(BlockProcessor.java:81)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:47)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:39)
        */
    protected void checkCRLs(java.security.cert.PKIXParameters r21, java.security.cert.X509Certificate r22, java.util.Date r23, java.security.cert.X509Certificate r24, java.security.PublicKey r25, java.util.Vector r26, int r27) throws org.bouncycastle.x509.CertPathReviewerException {
        /*
            Method dump skipped, instructions count: 1063
            To view this dump add '--comments-level debug' option
        */
        throw new UnsupportedOperationException("Method not decompiled: org.bouncycastle.x509.PKIXCertPathReviewer.checkCRLs(java.security.cert.PKIXParameters, java.security.cert.X509Certificate, java.util.Date, java.security.cert.X509Certificate, java.security.PublicKey, java.util.Vector, int):void");
    }

    protected void checkRevocation(PKIXParameters pKIXParameters, X509Certificate x509Certificate, Date date, X509Certificate x509Certificate2, PublicKey publicKey, Vector vector, Vector vector2, int i) throws CertPathReviewerException {
        checkCRLs(pKIXParameters, x509Certificate, date, x509Certificate2, publicKey, vector, i);
    }

    protected void doChecks() {
        if (!this.initialized) {
            throw new IllegalStateException("Object not initialized. Call init() first.");
        }
        if (this.notifications != null) {
            return;
        }
        int i = this.n;
        this.notifications = new List[i + 1];
        this.errors = new List[i + 1];
        int i2 = 0;
        while (true) {
            List[] listArr = this.notifications;
            if (i2 >= listArr.length) {
                checkSignatures();
                checkNameConstraints();
                checkPathLength();
                checkPolicy();
                checkCriticalExtensions();
                return;
            }
            listArr[i2] = new ArrayList();
            this.errors[i2] = new ArrayList();
            i2++;
        }
    }

    protected Vector getCRLDistUrls(CRLDistPoint cRLDistPoint) {
        Vector vector = new Vector();
        if (cRLDistPoint != null) {
            for (DistributionPoint distributionPoint : cRLDistPoint.getDistributionPoints()) {
                DistributionPointName distributionPoint2 = distributionPoint.getDistributionPoint();
                if (distributionPoint2.getType() == 0) {
                    GeneralName[] names = GeneralNames.getInstance(distributionPoint2.getName()).getNames();
                    for (int i = 0; i < names.length; i++) {
                        if (names[i].getTagNo() == 6) {
                            vector.add(((ASN1IA5String) names[i].getName()).getString());
                        }
                    }
                }
            }
        }
        return vector;
    }

    public CertPath getCertPath() {
        return this.certPath;
    }

    public int getCertPathSize() {
        return this.n;
    }

    public List getErrors(int i) {
        doChecks();
        return this.errors[i + 1];
    }

    public List[] getErrors() {
        doChecks();
        return this.errors;
    }

    public List getNotifications(int i) {
        doChecks();
        return this.notifications[i + 1];
    }

    public List[] getNotifications() {
        doChecks();
        return this.notifications;
    }

    protected Vector getOCSPUrls(AuthorityInformationAccess authorityInformationAccess) {
        Vector vector = new Vector();
        if (authorityInformationAccess != null) {
            AccessDescription[] accessDescriptions = authorityInformationAccess.getAccessDescriptions();
            for (int i = 0; i < accessDescriptions.length; i++) {
                if (accessDescriptions[i].getAccessMethod().equals((ASN1Primitive) AccessDescription.id_ad_ocsp)) {
                    GeneralName accessLocation = accessDescriptions[i].getAccessLocation();
                    if (accessLocation.getTagNo() == 6) {
                        vector.add(((ASN1IA5String) accessLocation.getName()).getString());
                    }
                }
            }
        }
        return vector;
    }

    public PolicyNode getPolicyTree() {
        doChecks();
        return this.policyTree;
    }

    public PublicKey getSubjectPublicKey() {
        doChecks();
        return this.subjectPublicKey;
    }

    public TrustAnchor getTrustAnchor() {
        doChecks();
        return this.trustAnchor;
    }

    protected Collection getTrustAnchors(X509Certificate x509Certificate, Set set) throws CertPathReviewerException {
        ArrayList arrayList = new ArrayList();
        Iterator it = set.iterator();
        X509CertSelector x509CertSelector = new X509CertSelector();
        try {
            x509CertSelector.setSubject(getEncodedIssuerPrincipal(x509Certificate).getEncoded());
            byte[] extensionValue = x509Certificate.getExtensionValue(Extension.authorityKeyIdentifier.getId());
            if (extensionValue != null) {
                AuthorityKeyIdentifier authorityKeyIdentifier = AuthorityKeyIdentifier.getInstance(ASN1Primitive.fromByteArray(((ASN1OctetString) ASN1Primitive.fromByteArray(extensionValue)).getOctets()));
                if (authorityKeyIdentifier.getAuthorityCertSerialNumber() != null) {
                    x509CertSelector.setSerialNumber(authorityKeyIdentifier.getAuthorityCertSerialNumber());
                }
            }
            while (it.hasNext()) {
                TrustAnchor trustAnchor = (TrustAnchor) it.next();
                if (trustAnchor.getTrustedCert() != null) {
                    if (x509CertSelector.match(trustAnchor.getTrustedCert())) {
                        arrayList.add(trustAnchor);
                    }
                } else if (trustAnchor.getCAName() != null && trustAnchor.getCAPublicKey() != null && getEncodedIssuerPrincipal(x509Certificate).equals(new X500Principal(trustAnchor.getCAName()))) {
                    arrayList.add(trustAnchor);
                }
            }
            return arrayList;
        } catch (IOException unused) {
            throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.trustAnchorIssuerError"));
        }
    }

    public void init(CertPath certPath, PKIXParameters pKIXParameters) throws CertPathReviewerException {
        if (this.initialized) {
            throw new IllegalStateException("object is already initialized!");
        }
        this.initialized = true;
        if (certPath == null) {
            throw new NullPointerException("certPath was null");
        }
        this.certPath = certPath;
        List<? extends Certificate> certificates = certPath.getCertificates();
        this.certs = certificates;
        this.n = certificates.size();
        if (this.certs.isEmpty()) {
            throw new CertPathReviewerException(new ErrorBundle(RESOURCE_NAME, "CertPathReviewer.emptyCertPath"));
        }
        this.pkixParams = (PKIXParameters) pKIXParameters.clone();
        Date date = new Date();
        this.currentDate = date;
        this.validDate = getValidityDate(this.pkixParams, date);
        this.notifications = null;
        this.errors = null;
        this.trustAnchor = null;
        this.subjectPublicKey = null;
        this.policyTree = null;
    }

    public boolean isValidCertPath() {
        doChecks();
        int i = 0;
        while (true) {
            List[] listArr = this.errors;
            if (i >= listArr.length) {
                return true;
            }
            if (!listArr[i].isEmpty()) {
                return false;
            }
            i++;
        }
    }
}
